# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ClusterApplicationConfigArgs',
    'ClusterBootstrapScriptArgs',
    'ClusterBootstrapScriptNodeSelectorArgs',
    'ClusterNodeAttributeArgs',
    'ClusterNodeGroupArgs',
    'ClusterNodeGroupCostOptimizedConfigArgs',
    'ClusterNodeGroupDataDiskArgs',
    'ClusterNodeGroupSpotBidPriceArgs',
    'ClusterNodeGroupSubscriptionConfigArgs',
    'ClusterNodeGroupSystemDiskArgs',
    'ClusterSubscriptionConfigArgs',
]

@pulumi.input_type
class ClusterApplicationConfigArgs:
    def __init__(__self__, *,
                 application_name: pulumi.Input[str],
                 config_file_name: pulumi.Input[str],
                 config_item_key: pulumi.Input[str],
                 config_item_value: pulumi.Input[str],
                 config_description: Optional[pulumi.Input[str]] = None,
                 config_scope: Optional[pulumi.Input[str]] = None,
                 node_group_id: Optional[pulumi.Input[str]] = None,
                 node_group_name: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] application_name: The application name of EMR cluster which has installed.
        :param pulumi.Input[str] config_file_name: The configuration file name of application installed.
        :param pulumi.Input[str] config_item_key: The configuration item key of application installed.
        :param pulumi.Input[str] config_item_value: The configuration item value of application installed.
        :param pulumi.Input[str] config_description: The configuration description of application installed.
        :param pulumi.Input[str] config_scope: The configuration scope of emr cluster. Supported value: CLUSTER or NODEGROUP.
        :param pulumi.Input[str] node_group_id: The configuration effected which node group id of emr cluster.
        :param pulumi.Input[str] node_group_name: The configuration effected which node group name of emr cluster.
        """
        pulumi.set(__self__, "application_name", application_name)
        pulumi.set(__self__, "config_file_name", config_file_name)
        pulumi.set(__self__, "config_item_key", config_item_key)
        pulumi.set(__self__, "config_item_value", config_item_value)
        if config_description is not None:
            pulumi.set(__self__, "config_description", config_description)
        if config_scope is not None:
            pulumi.set(__self__, "config_scope", config_scope)
        if node_group_id is not None:
            pulumi.set(__self__, "node_group_id", node_group_id)
        if node_group_name is not None:
            pulumi.set(__self__, "node_group_name", node_group_name)

    @property
    @pulumi.getter(name="applicationName")
    def application_name(self) -> pulumi.Input[str]:
        """
        The application name of EMR cluster which has installed.
        """
        return pulumi.get(self, "application_name")

    @application_name.setter
    def application_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "application_name", value)

    @property
    @pulumi.getter(name="configFileName")
    def config_file_name(self) -> pulumi.Input[str]:
        """
        The configuration file name of application installed.
        """
        return pulumi.get(self, "config_file_name")

    @config_file_name.setter
    def config_file_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "config_file_name", value)

    @property
    @pulumi.getter(name="configItemKey")
    def config_item_key(self) -> pulumi.Input[str]:
        """
        The configuration item key of application installed.
        """
        return pulumi.get(self, "config_item_key")

    @config_item_key.setter
    def config_item_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "config_item_key", value)

    @property
    @pulumi.getter(name="configItemValue")
    def config_item_value(self) -> pulumi.Input[str]:
        """
        The configuration item value of application installed.
        """
        return pulumi.get(self, "config_item_value")

    @config_item_value.setter
    def config_item_value(self, value: pulumi.Input[str]):
        pulumi.set(self, "config_item_value", value)

    @property
    @pulumi.getter(name="configDescription")
    def config_description(self) -> Optional[pulumi.Input[str]]:
        """
        The configuration description of application installed.
        """
        return pulumi.get(self, "config_description")

    @config_description.setter
    def config_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "config_description", value)

    @property
    @pulumi.getter(name="configScope")
    def config_scope(self) -> Optional[pulumi.Input[str]]:
        """
        The configuration scope of emr cluster. Supported value: CLUSTER or NODEGROUP.
        """
        return pulumi.get(self, "config_scope")

    @config_scope.setter
    def config_scope(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "config_scope", value)

    @property
    @pulumi.getter(name="nodeGroupId")
    def node_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The configuration effected which node group id of emr cluster.
        """
        return pulumi.get(self, "node_group_id")

    @node_group_id.setter
    def node_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "node_group_id", value)

    @property
    @pulumi.getter(name="nodeGroupName")
    def node_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The configuration effected which node group name of emr cluster.
        """
        return pulumi.get(self, "node_group_name")

    @node_group_name.setter
    def node_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "node_group_name", value)


@pulumi.input_type
class ClusterBootstrapScriptArgs:
    def __init__(__self__, *,
                 execution_fail_strategy: pulumi.Input[str],
                 execution_moment: pulumi.Input[str],
                 node_selector: pulumi.Input['ClusterBootstrapScriptNodeSelectorArgs'],
                 script_args: pulumi.Input[str],
                 script_name: pulumi.Input[str],
                 script_path: pulumi.Input[str],
                 priority: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] execution_fail_strategy: The bootstrap scripts execution fail strategy, ’FAILED_BLOCKED’ or ‘FAILED_CONTINUE’ .
        :param pulumi.Input[str] execution_moment: The bootstrap scripts execution moment, ’BEFORE_INSTALL’ or ‘AFTER_STARTED’ .
        :param pulumi.Input['ClusterBootstrapScriptNodeSelectorArgs'] node_selector: The bootstrap scripts execution target.
        :param pulumi.Input[str] script_args: The bootstrap script args, e.g. "--a=b".
        :param pulumi.Input[str] script_name: The bootstrap script name.
        :param pulumi.Input[str] script_path: The bootstrap script path, e.g. "oss://bucket/path".
        :param pulumi.Input[int] priority: The bootstrap scripts priority.
        """
        pulumi.set(__self__, "execution_fail_strategy", execution_fail_strategy)
        pulumi.set(__self__, "execution_moment", execution_moment)
        pulumi.set(__self__, "node_selector", node_selector)
        pulumi.set(__self__, "script_args", script_args)
        pulumi.set(__self__, "script_name", script_name)
        pulumi.set(__self__, "script_path", script_path)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)

    @property
    @pulumi.getter(name="executionFailStrategy")
    def execution_fail_strategy(self) -> pulumi.Input[str]:
        """
        The bootstrap scripts execution fail strategy, ’FAILED_BLOCKED’ or ‘FAILED_CONTINUE’ .
        """
        return pulumi.get(self, "execution_fail_strategy")

    @execution_fail_strategy.setter
    def execution_fail_strategy(self, value: pulumi.Input[str]):
        pulumi.set(self, "execution_fail_strategy", value)

    @property
    @pulumi.getter(name="executionMoment")
    def execution_moment(self) -> pulumi.Input[str]:
        """
        The bootstrap scripts execution moment, ’BEFORE_INSTALL’ or ‘AFTER_STARTED’ .
        """
        return pulumi.get(self, "execution_moment")

    @execution_moment.setter
    def execution_moment(self, value: pulumi.Input[str]):
        pulumi.set(self, "execution_moment", value)

    @property
    @pulumi.getter(name="nodeSelector")
    def node_selector(self) -> pulumi.Input['ClusterBootstrapScriptNodeSelectorArgs']:
        """
        The bootstrap scripts execution target.
        """
        return pulumi.get(self, "node_selector")

    @node_selector.setter
    def node_selector(self, value: pulumi.Input['ClusterBootstrapScriptNodeSelectorArgs']):
        pulumi.set(self, "node_selector", value)

    @property
    @pulumi.getter(name="scriptArgs")
    def script_args(self) -> pulumi.Input[str]:
        """
        The bootstrap script args, e.g. "--a=b".
        """
        return pulumi.get(self, "script_args")

    @script_args.setter
    def script_args(self, value: pulumi.Input[str]):
        pulumi.set(self, "script_args", value)

    @property
    @pulumi.getter(name="scriptName")
    def script_name(self) -> pulumi.Input[str]:
        """
        The bootstrap script name.
        """
        return pulumi.get(self, "script_name")

    @script_name.setter
    def script_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "script_name", value)

    @property
    @pulumi.getter(name="scriptPath")
    def script_path(self) -> pulumi.Input[str]:
        """
        The bootstrap script path, e.g. "oss://bucket/path".
        """
        return pulumi.get(self, "script_path")

    @script_path.setter
    def script_path(self, value: pulumi.Input[str]):
        pulumi.set(self, "script_path", value)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[int]]:
        """
        The bootstrap scripts priority.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "priority", value)


@pulumi.input_type
class ClusterBootstrapScriptNodeSelectorArgs:
    def __init__(__self__, *,
                 node_select_type: pulumi.Input[str],
                 node_group_id: Optional[pulumi.Input[str]] = None,
                 node_group_name: Optional[pulumi.Input[str]] = None,
                 node_group_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 node_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[str] node_select_type: The bootstrap scripts execution target node select type. Supported value: NODE, NODEGROUP or CLUSTER.
        :param pulumi.Input[str] node_group_id: The configuration effected which node group id of emr cluster.
        :param pulumi.Input[str] node_group_name: The configuration effected which node group name of emr cluster.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] node_group_types: The bootstrap scripts execution target node group types.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] node_names: The bootstrap scripts execution target node names.
        """
        pulumi.set(__self__, "node_select_type", node_select_type)
        if node_group_id is not None:
            pulumi.set(__self__, "node_group_id", node_group_id)
        if node_group_name is not None:
            pulumi.set(__self__, "node_group_name", node_group_name)
        if node_group_types is not None:
            pulumi.set(__self__, "node_group_types", node_group_types)
        if node_names is not None:
            pulumi.set(__self__, "node_names", node_names)

    @property
    @pulumi.getter(name="nodeSelectType")
    def node_select_type(self) -> pulumi.Input[str]:
        """
        The bootstrap scripts execution target node select type. Supported value: NODE, NODEGROUP or CLUSTER.
        """
        return pulumi.get(self, "node_select_type")

    @node_select_type.setter
    def node_select_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "node_select_type", value)

    @property
    @pulumi.getter(name="nodeGroupId")
    def node_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The configuration effected which node group id of emr cluster.
        """
        return pulumi.get(self, "node_group_id")

    @node_group_id.setter
    def node_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "node_group_id", value)

    @property
    @pulumi.getter(name="nodeGroupName")
    def node_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The configuration effected which node group name of emr cluster.
        """
        return pulumi.get(self, "node_group_name")

    @node_group_name.setter
    def node_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "node_group_name", value)

    @property
    @pulumi.getter(name="nodeGroupTypes")
    def node_group_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The bootstrap scripts execution target node group types.
        """
        return pulumi.get(self, "node_group_types")

    @node_group_types.setter
    def node_group_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "node_group_types", value)

    @property
    @pulumi.getter(name="nodeNames")
    def node_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The bootstrap scripts execution target node names.
        """
        return pulumi.get(self, "node_names")

    @node_names.setter
    def node_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "node_names", value)


@pulumi.input_type
class ClusterNodeAttributeArgs:
    def __init__(__self__, *,
                 key_pair_name: pulumi.Input[str],
                 ram_role: pulumi.Input[str],
                 security_group_id: pulumi.Input[str],
                 vpc_id: pulumi.Input[str],
                 zone_id: pulumi.Input[str],
                 data_disk_encrypted: Optional[pulumi.Input[bool]] = None,
                 data_disk_kms_key_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] key_pair_name: The name of the key pair.
        :param pulumi.Input[str] ram_role: Alicloud EMR uses roles to perform actions on your behalf when provisioning cluster resources, running applications, dynamically scaling resources. EMR uses the following roles when interacting with other Alicloud services. Default value is AliyunEmrEcsDefaultRole.
        :param pulumi.Input[str] security_group_id: Security Group ID for Cluster.
        :param pulumi.Input[str] vpc_id: Used to retrieve instances belong to specified VPC.
        :param pulumi.Input[str] zone_id: Zone ID, e.g. cn-hangzhou-i
        :param pulumi.Input[bool] data_disk_encrypted: Whether to enable data disk encryption.
        :param pulumi.Input[str] data_disk_kms_key_id: The kms key id used to encrypt the data disk. It takes effect when data_disk_encrypted is true.
        """
        pulumi.set(__self__, "key_pair_name", key_pair_name)
        pulumi.set(__self__, "ram_role", ram_role)
        pulumi.set(__self__, "security_group_id", security_group_id)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "zone_id", zone_id)
        if data_disk_encrypted is not None:
            pulumi.set(__self__, "data_disk_encrypted", data_disk_encrypted)
        if data_disk_kms_key_id is not None:
            pulumi.set(__self__, "data_disk_kms_key_id", data_disk_kms_key_id)

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> pulumi.Input[str]:
        """
        The name of the key pair.
        """
        return pulumi.get(self, "key_pair_name")

    @key_pair_name.setter
    def key_pair_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "key_pair_name", value)

    @property
    @pulumi.getter(name="ramRole")
    def ram_role(self) -> pulumi.Input[str]:
        """
        Alicloud EMR uses roles to perform actions on your behalf when provisioning cluster resources, running applications, dynamically scaling resources. EMR uses the following roles when interacting with other Alicloud services. Default value is AliyunEmrEcsDefaultRole.
        """
        return pulumi.get(self, "ram_role")

    @ram_role.setter
    def ram_role(self, value: pulumi.Input[str]):
        pulumi.set(self, "ram_role", value)

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> pulumi.Input[str]:
        """
        Security Group ID for Cluster.
        """
        return pulumi.get(self, "security_group_id")

    @security_group_id.setter
    def security_group_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "security_group_id", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[str]:
        """
        Used to retrieve instances belong to specified VPC.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Input[str]:
        """
        Zone ID, e.g. cn-hangzhou-i
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "zone_id", value)

    @property
    @pulumi.getter(name="dataDiskEncrypted")
    def data_disk_encrypted(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to enable data disk encryption.
        """
        return pulumi.get(self, "data_disk_encrypted")

    @data_disk_encrypted.setter
    def data_disk_encrypted(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "data_disk_encrypted", value)

    @property
    @pulumi.getter(name="dataDiskKmsKeyId")
    def data_disk_kms_key_id(self) -> Optional[pulumi.Input[str]]:
        """
        The kms key id used to encrypt the data disk. It takes effect when data_disk_encrypted is true.
        """
        return pulumi.get(self, "data_disk_kms_key_id")

    @data_disk_kms_key_id.setter
    def data_disk_kms_key_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_disk_kms_key_id", value)


@pulumi.input_type
class ClusterNodeGroupArgs:
    def __init__(__self__, *,
                 data_disks: pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupDataDiskArgs']]],
                 instance_types: pulumi.Input[Sequence[pulumi.Input[str]]],
                 node_count: pulumi.Input[int],
                 node_group_name: pulumi.Input[str],
                 node_group_type: pulumi.Input[str],
                 system_disk: pulumi.Input['ClusterNodeGroupSystemDiskArgs'],
                 additional_security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cost_optimized_config: Optional[pulumi.Input['ClusterNodeGroupCostOptimizedConfigArgs']] = None,
                 graceful_shutdown: Optional[pulumi.Input[bool]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 spot_bid_prices: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupSpotBidPriceArgs']]]] = None,
                 spot_instance_remedy: Optional[pulumi.Input[bool]] = None,
                 subscription_config: Optional[pulumi.Input['ClusterNodeGroupSubscriptionConfigArgs']] = None,
                 vswitch_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 with_public_ip: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupDataDiskArgs']]] data_disks: Host Ecs data disks information in this node group.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] instance_types: Host Ecs instance types.
        :param pulumi.Input[int] node_count: Host Ecs number in this node group.
        :param pulumi.Input[str] node_group_name: The configuration effected which node group name of emr cluster.
        :param pulumi.Input[str] node_group_type: The node group type of emr cluster, supported value: MASTER, CORE or TASK.
        :param pulumi.Input['ClusterNodeGroupSystemDiskArgs'] system_disk: Host Ecs system disk information in this node group.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] additional_security_group_ids: Additional security Group IDS for Cluster, you can also specify this key for each node group.
        :param pulumi.Input['ClusterNodeGroupCostOptimizedConfigArgs'] cost_optimized_config: The detail cost optimized configuration of emr cluster.
        :param pulumi.Input[bool] graceful_shutdown: Enable emr cluster of task node graceful decommission, ’true’ or ‘false’ .
        :param pulumi.Input[str] payment_type: Payment Type for this cluster. Supported value: PayAsYouGo or Subscription.
        :param pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupSpotBidPriceArgs']]] spot_bid_prices: The spot bid prices of a PayAsYouGo instance.
        :param pulumi.Input[bool] spot_instance_remedy: Whether to replace spot instances with newly created spot/onDemand instance when receive a spot recycling message.
        :param pulumi.Input['ClusterNodeGroupSubscriptionConfigArgs'] subscription_config: The detail configuration of subscription payment type.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] vswitch_ids: Global vSwitch ids, you can also specify it in node group.
        :param pulumi.Input[bool] with_public_ip: Whether the node has a public IP address enabled.
        """
        pulumi.set(__self__, "data_disks", data_disks)
        pulumi.set(__self__, "instance_types", instance_types)
        pulumi.set(__self__, "node_count", node_count)
        pulumi.set(__self__, "node_group_name", node_group_name)
        pulumi.set(__self__, "node_group_type", node_group_type)
        pulumi.set(__self__, "system_disk", system_disk)
        if additional_security_group_ids is not None:
            pulumi.set(__self__, "additional_security_group_ids", additional_security_group_ids)
        if cost_optimized_config is not None:
            pulumi.set(__self__, "cost_optimized_config", cost_optimized_config)
        if graceful_shutdown is not None:
            pulumi.set(__self__, "graceful_shutdown", graceful_shutdown)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if spot_bid_prices is not None:
            pulumi.set(__self__, "spot_bid_prices", spot_bid_prices)
        if spot_instance_remedy is not None:
            pulumi.set(__self__, "spot_instance_remedy", spot_instance_remedy)
        if subscription_config is not None:
            pulumi.set(__self__, "subscription_config", subscription_config)
        if vswitch_ids is not None:
            pulumi.set(__self__, "vswitch_ids", vswitch_ids)
        if with_public_ip is not None:
            pulumi.set(__self__, "with_public_ip", with_public_ip)

    @property
    @pulumi.getter(name="dataDisks")
    def data_disks(self) -> pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupDataDiskArgs']]]:
        """
        Host Ecs data disks information in this node group.
        """
        return pulumi.get(self, "data_disks")

    @data_disks.setter
    def data_disks(self, value: pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupDataDiskArgs']]]):
        pulumi.set(self, "data_disks", value)

    @property
    @pulumi.getter(name="instanceTypes")
    def instance_types(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Host Ecs instance types.
        """
        return pulumi.get(self, "instance_types")

    @instance_types.setter
    def instance_types(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "instance_types", value)

    @property
    @pulumi.getter(name="nodeCount")
    def node_count(self) -> pulumi.Input[int]:
        """
        Host Ecs number in this node group.
        """
        return pulumi.get(self, "node_count")

    @node_count.setter
    def node_count(self, value: pulumi.Input[int]):
        pulumi.set(self, "node_count", value)

    @property
    @pulumi.getter(name="nodeGroupName")
    def node_group_name(self) -> pulumi.Input[str]:
        """
        The configuration effected which node group name of emr cluster.
        """
        return pulumi.get(self, "node_group_name")

    @node_group_name.setter
    def node_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "node_group_name", value)

    @property
    @pulumi.getter(name="nodeGroupType")
    def node_group_type(self) -> pulumi.Input[str]:
        """
        The node group type of emr cluster, supported value: MASTER, CORE or TASK.
        """
        return pulumi.get(self, "node_group_type")

    @node_group_type.setter
    def node_group_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "node_group_type", value)

    @property
    @pulumi.getter(name="systemDisk")
    def system_disk(self) -> pulumi.Input['ClusterNodeGroupSystemDiskArgs']:
        """
        Host Ecs system disk information in this node group.
        """
        return pulumi.get(self, "system_disk")

    @system_disk.setter
    def system_disk(self, value: pulumi.Input['ClusterNodeGroupSystemDiskArgs']):
        pulumi.set(self, "system_disk", value)

    @property
    @pulumi.getter(name="additionalSecurityGroupIds")
    def additional_security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Additional security Group IDS for Cluster, you can also specify this key for each node group.
        """
        return pulumi.get(self, "additional_security_group_ids")

    @additional_security_group_ids.setter
    def additional_security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "additional_security_group_ids", value)

    @property
    @pulumi.getter(name="costOptimizedConfig")
    def cost_optimized_config(self) -> Optional[pulumi.Input['ClusterNodeGroupCostOptimizedConfigArgs']]:
        """
        The detail cost optimized configuration of emr cluster.
        """
        return pulumi.get(self, "cost_optimized_config")

    @cost_optimized_config.setter
    def cost_optimized_config(self, value: Optional[pulumi.Input['ClusterNodeGroupCostOptimizedConfigArgs']]):
        pulumi.set(self, "cost_optimized_config", value)

    @property
    @pulumi.getter(name="gracefulShutdown")
    def graceful_shutdown(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable emr cluster of task node graceful decommission, ’true’ or ‘false’ .
        """
        return pulumi.get(self, "graceful_shutdown")

    @graceful_shutdown.setter
    def graceful_shutdown(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "graceful_shutdown", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[str]]:
        """
        Payment Type for this cluster. Supported value: PayAsYouGo or Subscription.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="spotBidPrices")
    def spot_bid_prices(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupSpotBidPriceArgs']]]]:
        """
        The spot bid prices of a PayAsYouGo instance.
        """
        return pulumi.get(self, "spot_bid_prices")

    @spot_bid_prices.setter
    def spot_bid_prices(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupSpotBidPriceArgs']]]]):
        pulumi.set(self, "spot_bid_prices", value)

    @property
    @pulumi.getter(name="spotInstanceRemedy")
    def spot_instance_remedy(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to replace spot instances with newly created spot/onDemand instance when receive a spot recycling message.
        """
        return pulumi.get(self, "spot_instance_remedy")

    @spot_instance_remedy.setter
    def spot_instance_remedy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "spot_instance_remedy", value)

    @property
    @pulumi.getter(name="subscriptionConfig")
    def subscription_config(self) -> Optional[pulumi.Input['ClusterNodeGroupSubscriptionConfigArgs']]:
        """
        The detail configuration of subscription payment type.
        """
        return pulumi.get(self, "subscription_config")

    @subscription_config.setter
    def subscription_config(self, value: Optional[pulumi.Input['ClusterNodeGroupSubscriptionConfigArgs']]):
        pulumi.set(self, "subscription_config", value)

    @property
    @pulumi.getter(name="vswitchIds")
    def vswitch_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Global vSwitch ids, you can also specify it in node group.
        """
        return pulumi.get(self, "vswitch_ids")

    @vswitch_ids.setter
    def vswitch_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "vswitch_ids", value)

    @property
    @pulumi.getter(name="withPublicIp")
    def with_public_ip(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the node has a public IP address enabled.
        """
        return pulumi.get(self, "with_public_ip")

    @with_public_ip.setter
    def with_public_ip(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "with_public_ip", value)


@pulumi.input_type
class ClusterNodeGroupCostOptimizedConfigArgs:
    def __init__(__self__, *,
                 on_demand_base_capacity: pulumi.Input[int],
                 on_demand_percentage_above_base_capacity: pulumi.Input[int],
                 spot_instance_pools: pulumi.Input[int]):
        """
        :param pulumi.Input[int] on_demand_base_capacity: The cost optimized configuration which on demand based capacity.
        :param pulumi.Input[int] on_demand_percentage_above_base_capacity: The cost optimized configuration which on demand percentage above based capacity.
        :param pulumi.Input[int] spot_instance_pools: The cost optimized configuration with spot instance pools.
        """
        pulumi.set(__self__, "on_demand_base_capacity", on_demand_base_capacity)
        pulumi.set(__self__, "on_demand_percentage_above_base_capacity", on_demand_percentage_above_base_capacity)
        pulumi.set(__self__, "spot_instance_pools", spot_instance_pools)

    @property
    @pulumi.getter(name="onDemandBaseCapacity")
    def on_demand_base_capacity(self) -> pulumi.Input[int]:
        """
        The cost optimized configuration which on demand based capacity.
        """
        return pulumi.get(self, "on_demand_base_capacity")

    @on_demand_base_capacity.setter
    def on_demand_base_capacity(self, value: pulumi.Input[int]):
        pulumi.set(self, "on_demand_base_capacity", value)

    @property
    @pulumi.getter(name="onDemandPercentageAboveBaseCapacity")
    def on_demand_percentage_above_base_capacity(self) -> pulumi.Input[int]:
        """
        The cost optimized configuration which on demand percentage above based capacity.
        """
        return pulumi.get(self, "on_demand_percentage_above_base_capacity")

    @on_demand_percentage_above_base_capacity.setter
    def on_demand_percentage_above_base_capacity(self, value: pulumi.Input[int]):
        pulumi.set(self, "on_demand_percentage_above_base_capacity", value)

    @property
    @pulumi.getter(name="spotInstancePools")
    def spot_instance_pools(self) -> pulumi.Input[int]:
        """
        The cost optimized configuration with spot instance pools.
        """
        return pulumi.get(self, "spot_instance_pools")

    @spot_instance_pools.setter
    def spot_instance_pools(self, value: pulumi.Input[int]):
        pulumi.set(self, "spot_instance_pools", value)


@pulumi.input_type
class ClusterNodeGroupDataDiskArgs:
    def __init__(__self__, *,
                 category: pulumi.Input[str],
                 size: pulumi.Input[int],
                 count: Optional[pulumi.Input[int]] = None,
                 performance_level: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] category: The type of the data disk. Valid values: `cloud_efficiency` and `cloud_essd`.
        :param pulumi.Input[int] size: The size of a data disk, at least 40. Unit: GiB.
        :param pulumi.Input[int] count: The count of a data disk.
        :param pulumi.Input[str] performance_level: Worker node data disk performance level, when `category` values `cloud_essd`, the optional values are `PL0`, `PL1`, `PL2` or `PL3`, but the specific performance level is related to the disk capacity.
        """
        pulumi.set(__self__, "category", category)
        pulumi.set(__self__, "size", size)
        if count is not None:
            pulumi.set(__self__, "count", count)
        if performance_level is not None:
            pulumi.set(__self__, "performance_level", performance_level)

    @property
    @pulumi.getter
    def category(self) -> pulumi.Input[str]:
        """
        The type of the data disk. Valid values: `cloud_efficiency` and `cloud_essd`.
        """
        return pulumi.get(self, "category")

    @category.setter
    def category(self, value: pulumi.Input[str]):
        pulumi.set(self, "category", value)

    @property
    @pulumi.getter
    def size(self) -> pulumi.Input[int]:
        """
        The size of a data disk, at least 40. Unit: GiB.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: pulumi.Input[int]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter
    def count(self) -> Optional[pulumi.Input[int]]:
        """
        The count of a data disk.
        """
        return pulumi.get(self, "count")

    @count.setter
    def count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "count", value)

    @property
    @pulumi.getter(name="performanceLevel")
    def performance_level(self) -> Optional[pulumi.Input[str]]:
        """
        Worker node data disk performance level, when `category` values `cloud_essd`, the optional values are `PL0`, `PL1`, `PL2` or `PL3`, but the specific performance level is related to the disk capacity.
        """
        return pulumi.get(self, "performance_level")

    @performance_level.setter
    def performance_level(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "performance_level", value)


@pulumi.input_type
class ClusterNodeGroupSpotBidPriceArgs:
    def __init__(__self__, *,
                 bid_price: pulumi.Input[int],
                 instance_type: pulumi.Input[str]):
        """
        :param pulumi.Input[int] bid_price: The spot bid price of a PayAsYouGo instance.
        :param pulumi.Input[str] instance_type: Host Ecs instance type.
        """
        pulumi.set(__self__, "bid_price", bid_price)
        pulumi.set(__self__, "instance_type", instance_type)

    @property
    @pulumi.getter(name="bidPrice")
    def bid_price(self) -> pulumi.Input[int]:
        """
        The spot bid price of a PayAsYouGo instance.
        """
        return pulumi.get(self, "bid_price")

    @bid_price.setter
    def bid_price(self, value: pulumi.Input[int]):
        pulumi.set(self, "bid_price", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Input[str]:
        """
        Host Ecs instance type.
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_type", value)


@pulumi.input_type
class ClusterNodeGroupSubscriptionConfigArgs:
    def __init__(__self__, *,
                 payment_duration: pulumi.Input[int],
                 payment_duration_unit: pulumi.Input[str],
                 auto_renew: Optional[pulumi.Input[bool]] = None,
                 auto_renew_duration: Optional[pulumi.Input[int]] = None,
                 auto_renew_duration_unit: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[int] payment_duration: If paymentType is Subscription, this should be specified. Supported value: 1、2、3、4、5、6、7、8、9、12、24、36、48.
        :param pulumi.Input[str] payment_duration_unit: If paymentType is Subscription, this should be specified. Supported value: Month or Year.
        :param pulumi.Input[bool] auto_renew: Auto renew for prepaid, ’true’ or ‘false’ . Default value: false.
        :param pulumi.Input[int] auto_renew_duration: If paymentType is Subscription, this should be specified. Supported value: 1、2、3、4、5、6、7、8、9、12、24、36、48.
        :param pulumi.Input[str] auto_renew_duration_unit: If paymentType is Subscription, this should be specified. Supported value: Month or Year.
        """
        pulumi.set(__self__, "payment_duration", payment_duration)
        pulumi.set(__self__, "payment_duration_unit", payment_duration_unit)
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if auto_renew_duration is not None:
            pulumi.set(__self__, "auto_renew_duration", auto_renew_duration)
        if auto_renew_duration_unit is not None:
            pulumi.set(__self__, "auto_renew_duration_unit", auto_renew_duration_unit)

    @property
    @pulumi.getter(name="paymentDuration")
    def payment_duration(self) -> pulumi.Input[int]:
        """
        If paymentType is Subscription, this should be specified. Supported value: 1、2、3、4、5、6、7、8、9、12、24、36、48.
        """
        return pulumi.get(self, "payment_duration")

    @payment_duration.setter
    def payment_duration(self, value: pulumi.Input[int]):
        pulumi.set(self, "payment_duration", value)

    @property
    @pulumi.getter(name="paymentDurationUnit")
    def payment_duration_unit(self) -> pulumi.Input[str]:
        """
        If paymentType is Subscription, this should be specified. Supported value: Month or Year.
        """
        return pulumi.get(self, "payment_duration_unit")

    @payment_duration_unit.setter
    def payment_duration_unit(self, value: pulumi.Input[str]):
        pulumi.set(self, "payment_duration_unit", value)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[bool]]:
        """
        Auto renew for prepaid, ’true’ or ‘false’ . Default value: false.
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="autoRenewDuration")
    def auto_renew_duration(self) -> Optional[pulumi.Input[int]]:
        """
        If paymentType is Subscription, this should be specified. Supported value: 1、2、3、4、5、6、7、8、9、12、24、36、48.
        """
        return pulumi.get(self, "auto_renew_duration")

    @auto_renew_duration.setter
    def auto_renew_duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "auto_renew_duration", value)

    @property
    @pulumi.getter(name="autoRenewDurationUnit")
    def auto_renew_duration_unit(self) -> Optional[pulumi.Input[str]]:
        """
        If paymentType is Subscription, this should be specified. Supported value: Month or Year.
        """
        return pulumi.get(self, "auto_renew_duration_unit")

    @auto_renew_duration_unit.setter
    def auto_renew_duration_unit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auto_renew_duration_unit", value)


@pulumi.input_type
class ClusterNodeGroupSystemDiskArgs:
    def __init__(__self__, *,
                 category: pulumi.Input[str],
                 size: pulumi.Input[int],
                 count: Optional[pulumi.Input[int]] = None,
                 performance_level: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] category: The type of the data disk. Valid values: `cloud_efficiency` and `cloud_essd`.
        :param pulumi.Input[int] size: The size of a data disk, at least 40. Unit: GiB.
        :param pulumi.Input[int] count: The count of a data disk.
        :param pulumi.Input[str] performance_level: Worker node data disk performance level, when `category` values `cloud_essd`, the optional values are `PL0`, `PL1`, `PL2` or `PL3`, but the specific performance level is related to the disk capacity.
        """
        pulumi.set(__self__, "category", category)
        pulumi.set(__self__, "size", size)
        if count is not None:
            pulumi.set(__self__, "count", count)
        if performance_level is not None:
            pulumi.set(__self__, "performance_level", performance_level)

    @property
    @pulumi.getter
    def category(self) -> pulumi.Input[str]:
        """
        The type of the data disk. Valid values: `cloud_efficiency` and `cloud_essd`.
        """
        return pulumi.get(self, "category")

    @category.setter
    def category(self, value: pulumi.Input[str]):
        pulumi.set(self, "category", value)

    @property
    @pulumi.getter
    def size(self) -> pulumi.Input[int]:
        """
        The size of a data disk, at least 40. Unit: GiB.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: pulumi.Input[int]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter
    def count(self) -> Optional[pulumi.Input[int]]:
        """
        The count of a data disk.
        """
        return pulumi.get(self, "count")

    @count.setter
    def count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "count", value)

    @property
    @pulumi.getter(name="performanceLevel")
    def performance_level(self) -> Optional[pulumi.Input[str]]:
        """
        Worker node data disk performance level, when `category` values `cloud_essd`, the optional values are `PL0`, `PL1`, `PL2` or `PL3`, but the specific performance level is related to the disk capacity.
        """
        return pulumi.get(self, "performance_level")

    @performance_level.setter
    def performance_level(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "performance_level", value)


@pulumi.input_type
class ClusterSubscriptionConfigArgs:
    def __init__(__self__, *,
                 payment_duration: pulumi.Input[int],
                 payment_duration_unit: pulumi.Input[str],
                 auto_renew: Optional[pulumi.Input[bool]] = None,
                 auto_renew_duration: Optional[pulumi.Input[int]] = None,
                 auto_renew_duration_unit: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[int] payment_duration: If paymentType is Subscription, this should be specified. Supported value: 1、2、3、4、5、6、7、8、9、12、24、36、48.
        :param pulumi.Input[str] payment_duration_unit: If paymentType is Subscription, this should be specified. Supported value: Month or Year.
        :param pulumi.Input[bool] auto_renew: Auto renew for prepaid, ’true’ or ‘false’ . Default value: false.
        :param pulumi.Input[int] auto_renew_duration: If paymentType is Subscription, this should be specified. Supported value: 1、2、3、4、5、6、7、8、9、12、24、36、48.
        :param pulumi.Input[str] auto_renew_duration_unit: If paymentType is Subscription, this should be specified. Supported value: Month or Year.
        """
        pulumi.set(__self__, "payment_duration", payment_duration)
        pulumi.set(__self__, "payment_duration_unit", payment_duration_unit)
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if auto_renew_duration is not None:
            pulumi.set(__self__, "auto_renew_duration", auto_renew_duration)
        if auto_renew_duration_unit is not None:
            pulumi.set(__self__, "auto_renew_duration_unit", auto_renew_duration_unit)

    @property
    @pulumi.getter(name="paymentDuration")
    def payment_duration(self) -> pulumi.Input[int]:
        """
        If paymentType is Subscription, this should be specified. Supported value: 1、2、3、4、5、6、7、8、9、12、24、36、48.
        """
        return pulumi.get(self, "payment_duration")

    @payment_duration.setter
    def payment_duration(self, value: pulumi.Input[int]):
        pulumi.set(self, "payment_duration", value)

    @property
    @pulumi.getter(name="paymentDurationUnit")
    def payment_duration_unit(self) -> pulumi.Input[str]:
        """
        If paymentType is Subscription, this should be specified. Supported value: Month or Year.
        """
        return pulumi.get(self, "payment_duration_unit")

    @payment_duration_unit.setter
    def payment_duration_unit(self, value: pulumi.Input[str]):
        pulumi.set(self, "payment_duration_unit", value)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[bool]]:
        """
        Auto renew for prepaid, ’true’ or ‘false’ . Default value: false.
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="autoRenewDuration")
    def auto_renew_duration(self) -> Optional[pulumi.Input[int]]:
        """
        If paymentType is Subscription, this should be specified. Supported value: 1、2、3、4、5、6、7、8、9、12、24、36、48.
        """
        return pulumi.get(self, "auto_renew_duration")

    @auto_renew_duration.setter
    def auto_renew_duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "auto_renew_duration", value)

    @property
    @pulumi.getter(name="autoRenewDurationUnit")
    def auto_renew_duration_unit(self) -> Optional[pulumi.Input[str]]:
        """
        If paymentType is Subscription, this should be specified. Supported value: Month or Year.
        """
        return pulumi.get(self, "auto_renew_duration_unit")

    @auto_renew_duration_unit.setter
    def auto_renew_duration_unit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auto_renew_duration_unit", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'DomainResourceProxyTypeArgs',
    'SchedulerRuleRuleArgs',
]

@pulumi.input_type
class DomainResourceProxyTypeArgs:
    def __init__(__self__, *,
                 proxy_ports: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 proxy_type: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[int]]] proxy_ports: the port number. This field is required and must be an integer. **NOTE:** From version 1.206.0, `proxy_ports` can be modified.
        :param pulumi.Input[str] proxy_type: the protocol type. This field is required and must be a string. Valid values: `http`, `https`, `websocket`, and `websockets`.
        """
        if proxy_ports is not None:
            pulumi.set(__self__, "proxy_ports", proxy_ports)
        if proxy_type is not None:
            pulumi.set(__self__, "proxy_type", proxy_type)

    @property
    @pulumi.getter(name="proxyPorts")
    def proxy_ports(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        the port number. This field is required and must be an integer. **NOTE:** From version 1.206.0, `proxy_ports` can be modified.
        """
        return pulumi.get(self, "proxy_ports")

    @proxy_ports.setter
    def proxy_ports(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "proxy_ports", value)

    @property
    @pulumi.getter(name="proxyType")
    def proxy_type(self) -> Optional[pulumi.Input[str]]:
        """
        the protocol type. This field is required and must be a string. Valid values: `http`, `https`, `websocket`, and `websockets`.
        """
        return pulumi.get(self, "proxy_type")

    @proxy_type.setter
    def proxy_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "proxy_type", value)


@pulumi.input_type
class SchedulerRuleRuleArgs:
    def __init__(__self__, *,
                 priority: Optional[pulumi.Input[int]] = None,
                 region_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[int]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None,
                 value_type: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[int] priority: The priority of the rule.
        :param pulumi.Input[str] region_id: The region where the interaction resource that is used in the scheduling rule is deployed. **NOTE:** This parameter is returned only if the RuleType parameter is set to 2.
        :param pulumi.Input[int] status: The status of the scheduling rule.
        :param pulumi.Input[str] type: The address type of the interaction resource. Valid values:
               `A`: IPv4 address.
               `CNAME`: CNAME record.
        :param pulumi.Input[str] value: The address of the interaction resource.
        :param pulumi.Input[int] value_type: Required. The type of the linked resource. It is an Integer. Valid values:
               `1`: The IP address of Anti-DDoS Pro or Anti-DDoS Premium
               `2`: the IP address of the interaction resource (in the tiered protection scenario)
               `3`: the IP address used to accelerate access (in the network acceleration scenario)
               `6` the IP address of the interaction resource (in the cloud service interaction scenario)
        """
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if region_id is not None:
            pulumi.set(__self__, "region_id", region_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value is not None:
            pulumi.set(__self__, "value", value)
        if value_type is not None:
            pulumi.set(__self__, "value_type", value_type)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[int]]:
        """
        The priority of the rule.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The region where the interaction resource that is used in the scheduling rule is deployed. **NOTE:** This parameter is returned only if the RuleType parameter is set to 2.
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[int]]:
        """
        The status of the scheduling rule.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The address type of the interaction resource. Valid values:
        `A`: IPv4 address.
        `CNAME`: CNAME record.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        """
        The address of the interaction resource.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)

    @property
    @pulumi.getter(name="valueType")
    def value_type(self) -> Optional[pulumi.Input[int]]:
        """
        Required. The type of the linked resource. It is an Integer. Valid values:
        `1`: The IP address of Anti-DDoS Pro or Anti-DDoS Premium
        `2`: the IP address of the interaction resource (in the tiered protection scenario)
        `3`: the IP address used to accelerate access (in the network acceleration scenario)
        `6` the IP address of the interaction resource (in the cloud service interaction scenario)
        """
        return pulumi.get(self, "value_type")

    @value_type.setter
    def value_type(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "value_type", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ConsumerChannelArgs', 'ConsumerChannel']

@pulumi.input_type
class ConsumerChannelArgs:
    def __init__(__self__, *,
                 consumer_group_name: pulumi.Input[str],
                 consumer_group_password: pulumi.Input[str],
                 consumer_group_user_name: pulumi.Input[str],
                 dts_instance_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a ConsumerChannel resource.
        :param pulumi.Input[str] consumer_group_name: The name of the consumer group.
        :param pulumi.Input[str] consumer_group_password: The password of the consumer group account. The length of the `consumer_group_password` is limited to `8` to `32` characters. It can contain two or more of the following characters: uppercase letters, lowercase letters, digits, and special characters.
        :param pulumi.Input[str] consumer_group_user_name: The username of the consumer group. The length of the `consumer_group_user_name` is limited to `1` to `16` characters. It can contain one or more of the following characters: uppercase letters, lowercase letters, digits, and underscores (_).
        :param pulumi.Input[str] dts_instance_id: The ID of the subscription instance.
        """
        pulumi.set(__self__, "consumer_group_name", consumer_group_name)
        pulumi.set(__self__, "consumer_group_password", consumer_group_password)
        pulumi.set(__self__, "consumer_group_user_name", consumer_group_user_name)
        pulumi.set(__self__, "dts_instance_id", dts_instance_id)

    @property
    @pulumi.getter(name="consumerGroupName")
    def consumer_group_name(self) -> pulumi.Input[str]:
        """
        The name of the consumer group.
        """
        return pulumi.get(self, "consumer_group_name")

    @consumer_group_name.setter
    def consumer_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "consumer_group_name", value)

    @property
    @pulumi.getter(name="consumerGroupPassword")
    def consumer_group_password(self) -> pulumi.Input[str]:
        """
        The password of the consumer group account. The length of the `consumer_group_password` is limited to `8` to `32` characters. It can contain two or more of the following characters: uppercase letters, lowercase letters, digits, and special characters.
        """
        return pulumi.get(self, "consumer_group_password")

    @consumer_group_password.setter
    def consumer_group_password(self, value: pulumi.Input[str]):
        pulumi.set(self, "consumer_group_password", value)

    @property
    @pulumi.getter(name="consumerGroupUserName")
    def consumer_group_user_name(self) -> pulumi.Input[str]:
        """
        The username of the consumer group. The length of the `consumer_group_user_name` is limited to `1` to `16` characters. It can contain one or more of the following characters: uppercase letters, lowercase letters, digits, and underscores (_).
        """
        return pulumi.get(self, "consumer_group_user_name")

    @consumer_group_user_name.setter
    def consumer_group_user_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "consumer_group_user_name", value)

    @property
    @pulumi.getter(name="dtsInstanceId")
    def dts_instance_id(self) -> pulumi.Input[str]:
        """
        The ID of the subscription instance.
        """
        return pulumi.get(self, "dts_instance_id")

    @dts_instance_id.setter
    def dts_instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "dts_instance_id", value)


@pulumi.input_type
class _ConsumerChannelState:
    def __init__(__self__, *,
                 consumer_group_id: Optional[pulumi.Input[str]] = None,
                 consumer_group_name: Optional[pulumi.Input[str]] = None,
                 consumer_group_password: Optional[pulumi.Input[str]] = None,
                 consumer_group_user_name: Optional[pulumi.Input[str]] = None,
                 dts_instance_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ConsumerChannel resources.
        :param pulumi.Input[str] consumer_group_id: The ID of the consumer group.
        :param pulumi.Input[str] consumer_group_name: The name of the consumer group.
        :param pulumi.Input[str] consumer_group_password: The password of the consumer group account. The length of the `consumer_group_password` is limited to `8` to `32` characters. It can contain two or more of the following characters: uppercase letters, lowercase letters, digits, and special characters.
        :param pulumi.Input[str] consumer_group_user_name: The username of the consumer group. The length of the `consumer_group_user_name` is limited to `1` to `16` characters. It can contain one or more of the following characters: uppercase letters, lowercase letters, digits, and underscores (_).
        :param pulumi.Input[str] dts_instance_id: The ID of the subscription instance.
        """
        if consumer_group_id is not None:
            pulumi.set(__self__, "consumer_group_id", consumer_group_id)
        if consumer_group_name is not None:
            pulumi.set(__self__, "consumer_group_name", consumer_group_name)
        if consumer_group_password is not None:
            pulumi.set(__self__, "consumer_group_password", consumer_group_password)
        if consumer_group_user_name is not None:
            pulumi.set(__self__, "consumer_group_user_name", consumer_group_user_name)
        if dts_instance_id is not None:
            pulumi.set(__self__, "dts_instance_id", dts_instance_id)

    @property
    @pulumi.getter(name="consumerGroupId")
    def consumer_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the consumer group.
        """
        return pulumi.get(self, "consumer_group_id")

    @consumer_group_id.setter
    def consumer_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "consumer_group_id", value)

    @property
    @pulumi.getter(name="consumerGroupName")
    def consumer_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the consumer group.
        """
        return pulumi.get(self, "consumer_group_name")

    @consumer_group_name.setter
    def consumer_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "consumer_group_name", value)

    @property
    @pulumi.getter(name="consumerGroupPassword")
    def consumer_group_password(self) -> Optional[pulumi.Input[str]]:
        """
        The password of the consumer group account. The length of the `consumer_group_password` is limited to `8` to `32` characters. It can contain two or more of the following characters: uppercase letters, lowercase letters, digits, and special characters.
        """
        return pulumi.get(self, "consumer_group_password")

    @consumer_group_password.setter
    def consumer_group_password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "consumer_group_password", value)

    @property
    @pulumi.getter(name="consumerGroupUserName")
    def consumer_group_user_name(self) -> Optional[pulumi.Input[str]]:
        """
        The username of the consumer group. The length of the `consumer_group_user_name` is limited to `1` to `16` characters. It can contain one or more of the following characters: uppercase letters, lowercase letters, digits, and underscores (_).
        """
        return pulumi.get(self, "consumer_group_user_name")

    @consumer_group_user_name.setter
    def consumer_group_user_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "consumer_group_user_name", value)

    @property
    @pulumi.getter(name="dtsInstanceId")
    def dts_instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the subscription instance.
        """
        return pulumi.get(self, "dts_instance_id")

    @dts_instance_id.setter
    def dts_instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dts_instance_id", value)


class ConsumerChannel(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 consumer_group_name: Optional[pulumi.Input[str]] = None,
                 consumer_group_password: Optional[pulumi.Input[str]] = None,
                 consumer_group_user_name: Optional[pulumi.Input[str]] = None,
                 dts_instance_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a DTS Consumer Channel resource.

        For information about DTS Consumer Channel and how to use it, see [What is Consumer Channel](https://www.alibabacloud.com/help/en/doc-detail/264593.htm).

        > **NOTE:** Available since v1.146.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        example_regions = alicloud.get_regions(current=True)
        example_zones = alicloud.rds.get_zones(engine="MySQL",
            engine_version="8.0",
            instance_charge_type="PostPaid",
            category="Basic",
            db_instance_storage_type="cloud_essd")
        example_instance_classes = alicloud.rds.get_instance_classes(zone_id=example_zones.zones[0].id,
            engine="MySQL",
            engine_version="8.0",
            instance_charge_type="PostPaid",
            category="Basic",
            db_instance_storage_type="cloud_essd")
        example_network = alicloud.vpc.Network("exampleNetwork",
            vpc_name=name,
            cidr_block="172.16.0.0/16")
        example_switch = alicloud.vpc.Switch("exampleSwitch",
            vpc_id=example_network.id,
            cidr_block="172.16.0.0/24",
            zone_id=example_zones.zones[0].id,
            vswitch_name=name)
        example_security_group = alicloud.ecs.SecurityGroup("exampleSecurityGroup", vpc_id=example_network.id)
        example_instance = alicloud.rds.Instance("exampleInstance",
            engine="MySQL",
            engine_version="8.0",
            instance_type=example_instance_classes.instance_classes[0].instance_class,
            instance_storage=example_instance_classes.instance_classes[0].storage_range.min,
            instance_charge_type="Postpaid",
            instance_name=name,
            vswitch_id=example_switch.id,
            monitoring_period=60,
            db_instance_storage_type="cloud_essd",
            security_group_ids=[example_security_group.id])
        example_rds_account = alicloud.rds.RdsAccount("exampleRdsAccount",
            db_instance_id=example_instance.id,
            account_name="example_name",
            account_password="example_1234")
        example_database = alicloud.rds.Database("exampleDatabase", instance_id=example_instance.id)
        example_account_privilege = alicloud.rds.AccountPrivilege("exampleAccountPrivilege",
            instance_id=example_instance.id,
            account_name=example_rds_account.name,
            privilege="ReadWrite",
            db_names=[example_database.name])
        example_subscription_job = alicloud.dts.SubscriptionJob("exampleSubscriptionJob",
            dts_job_name=name,
            payment_type="PayAsYouGo",
            source_endpoint_engine_name="MySQL",
            source_endpoint_region=example_regions.regions[0].id,
            source_endpoint_instance_type="RDS",
            source_endpoint_instance_id=example_instance.id,
            source_endpoint_database_name=example_database.name,
            source_endpoint_user_name=example_rds_account.account_name,
            source_endpoint_password=example_rds_account.account_password,
            db_list=pulumi.Output.all(example_database.name, example_database.name).apply(lambda exampleDatabaseName, exampleDatabaseName1: f"{{\\"{example_database_name}\\":{{\\"name\\":\\"{example_database_name1}\\",\\"all\\":true}}}}"),
            subscription_instance_network_type="vpc",
            subscription_instance_vpc_id=example_network.id,
            subscription_instance_vswitch_id=example_switch.id,
            status="Normal")
        example_consumer_channel = alicloud.dts.ConsumerChannel("exampleConsumerChannel",
            dts_instance_id=example_subscription_job.dts_instance_id,
            consumer_group_name=name,
            consumer_group_user_name="example",
            consumer_group_password="example1234")
        ```

        ## Import

        DTS Consumer Channel can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:dts/consumerChannel:ConsumerChannel example <dts_instance_id>:<consumer_group_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] consumer_group_name: The name of the consumer group.
        :param pulumi.Input[str] consumer_group_password: The password of the consumer group account. The length of the `consumer_group_password` is limited to `8` to `32` characters. It can contain two or more of the following characters: uppercase letters, lowercase letters, digits, and special characters.
        :param pulumi.Input[str] consumer_group_user_name: The username of the consumer group. The length of the `consumer_group_user_name` is limited to `1` to `16` characters. It can contain one or more of the following characters: uppercase letters, lowercase letters, digits, and underscores (_).
        :param pulumi.Input[str] dts_instance_id: The ID of the subscription instance.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConsumerChannelArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DTS Consumer Channel resource.

        For information about DTS Consumer Channel and how to use it, see [What is Consumer Channel](https://www.alibabacloud.com/help/en/doc-detail/264593.htm).

        > **NOTE:** Available since v1.146.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        example_regions = alicloud.get_regions(current=True)
        example_zones = alicloud.rds.get_zones(engine="MySQL",
            engine_version="8.0",
            instance_charge_type="PostPaid",
            category="Basic",
            db_instance_storage_type="cloud_essd")
        example_instance_classes = alicloud.rds.get_instance_classes(zone_id=example_zones.zones[0].id,
            engine="MySQL",
            engine_version="8.0",
            instance_charge_type="PostPaid",
            category="Basic",
            db_instance_storage_type="cloud_essd")
        example_network = alicloud.vpc.Network("exampleNetwork",
            vpc_name=name,
            cidr_block="172.16.0.0/16")
        example_switch = alicloud.vpc.Switch("exampleSwitch",
            vpc_id=example_network.id,
            cidr_block="172.16.0.0/24",
            zone_id=example_zones.zones[0].id,
            vswitch_name=name)
        example_security_group = alicloud.ecs.SecurityGroup("exampleSecurityGroup", vpc_id=example_network.id)
        example_instance = alicloud.rds.Instance("exampleInstance",
            engine="MySQL",
            engine_version="8.0",
            instance_type=example_instance_classes.instance_classes[0].instance_class,
            instance_storage=example_instance_classes.instance_classes[0].storage_range.min,
            instance_charge_type="Postpaid",
            instance_name=name,
            vswitch_id=example_switch.id,
            monitoring_period=60,
            db_instance_storage_type="cloud_essd",
            security_group_ids=[example_security_group.id])
        example_rds_account = alicloud.rds.RdsAccount("exampleRdsAccount",
            db_instance_id=example_instance.id,
            account_name="example_name",
            account_password="example_1234")
        example_database = alicloud.rds.Database("exampleDatabase", instance_id=example_instance.id)
        example_account_privilege = alicloud.rds.AccountPrivilege("exampleAccountPrivilege",
            instance_id=example_instance.id,
            account_name=example_rds_account.name,
            privilege="ReadWrite",
            db_names=[example_database.name])
        example_subscription_job = alicloud.dts.SubscriptionJob("exampleSubscriptionJob",
            dts_job_name=name,
            payment_type="PayAsYouGo",
            source_endpoint_engine_name="MySQL",
            source_endpoint_region=example_regions.regions[0].id,
            source_endpoint_instance_type="RDS",
            source_endpoint_instance_id=example_instance.id,
            source_endpoint_database_name=example_database.name,
            source_endpoint_user_name=example_rds_account.account_name,
            source_endpoint_password=example_rds_account.account_password,
            db_list=pulumi.Output.all(example_database.name, example_database.name).apply(lambda exampleDatabaseName, exampleDatabaseName1: f"{{\\"{example_database_name}\\":{{\\"name\\":\\"{example_database_name1}\\",\\"all\\":true}}}}"),
            subscription_instance_network_type="vpc",
            subscription_instance_vpc_id=example_network.id,
            subscription_instance_vswitch_id=example_switch.id,
            status="Normal")
        example_consumer_channel = alicloud.dts.ConsumerChannel("exampleConsumerChannel",
            dts_instance_id=example_subscription_job.dts_instance_id,
            consumer_group_name=name,
            consumer_group_user_name="example",
            consumer_group_password="example1234")
        ```

        ## Import

        DTS Consumer Channel can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:dts/consumerChannel:ConsumerChannel example <dts_instance_id>:<consumer_group_id>
        ```

        :param str resource_name: The name of the resource.
        :param ConsumerChannelArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConsumerChannelArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 consumer_group_name: Optional[pulumi.Input[str]] = None,
                 consumer_group_password: Optional[pulumi.Input[str]] = None,
                 consumer_group_user_name: Optional[pulumi.Input[str]] = None,
                 dts_instance_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConsumerChannelArgs.__new__(ConsumerChannelArgs)

            if consumer_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'consumer_group_name'")
            __props__.__dict__["consumer_group_name"] = consumer_group_name
            if consumer_group_password is None and not opts.urn:
                raise TypeError("Missing required property 'consumer_group_password'")
            __props__.__dict__["consumer_group_password"] = consumer_group_password
            if consumer_group_user_name is None and not opts.urn:
                raise TypeError("Missing required property 'consumer_group_user_name'")
            __props__.__dict__["consumer_group_user_name"] = consumer_group_user_name
            if dts_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'dts_instance_id'")
            __props__.__dict__["dts_instance_id"] = dts_instance_id
            __props__.__dict__["consumer_group_id"] = None
        super(ConsumerChannel, __self__).__init__(
            'alicloud:dts/consumerChannel:ConsumerChannel',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            consumer_group_id: Optional[pulumi.Input[str]] = None,
            consumer_group_name: Optional[pulumi.Input[str]] = None,
            consumer_group_password: Optional[pulumi.Input[str]] = None,
            consumer_group_user_name: Optional[pulumi.Input[str]] = None,
            dts_instance_id: Optional[pulumi.Input[str]] = None) -> 'ConsumerChannel':
        """
        Get an existing ConsumerChannel resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] consumer_group_id: The ID of the consumer group.
        :param pulumi.Input[str] consumer_group_name: The name of the consumer group.
        :param pulumi.Input[str] consumer_group_password: The password of the consumer group account. The length of the `consumer_group_password` is limited to `8` to `32` characters. It can contain two or more of the following characters: uppercase letters, lowercase letters, digits, and special characters.
        :param pulumi.Input[str] consumer_group_user_name: The username of the consumer group. The length of the `consumer_group_user_name` is limited to `1` to `16` characters. It can contain one or more of the following characters: uppercase letters, lowercase letters, digits, and underscores (_).
        :param pulumi.Input[str] dts_instance_id: The ID of the subscription instance.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConsumerChannelState.__new__(_ConsumerChannelState)

        __props__.__dict__["consumer_group_id"] = consumer_group_id
        __props__.__dict__["consumer_group_name"] = consumer_group_name
        __props__.__dict__["consumer_group_password"] = consumer_group_password
        __props__.__dict__["consumer_group_user_name"] = consumer_group_user_name
        __props__.__dict__["dts_instance_id"] = dts_instance_id
        return ConsumerChannel(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="consumerGroupId")
    def consumer_group_id(self) -> pulumi.Output[str]:
        """
        The ID of the consumer group.
        """
        return pulumi.get(self, "consumer_group_id")

    @property
    @pulumi.getter(name="consumerGroupName")
    def consumer_group_name(self) -> pulumi.Output[str]:
        """
        The name of the consumer group.
        """
        return pulumi.get(self, "consumer_group_name")

    @property
    @pulumi.getter(name="consumerGroupPassword")
    def consumer_group_password(self) -> pulumi.Output[str]:
        """
        The password of the consumer group account. The length of the `consumer_group_password` is limited to `8` to `32` characters. It can contain two or more of the following characters: uppercase letters, lowercase letters, digits, and special characters.
        """
        return pulumi.get(self, "consumer_group_password")

    @property
    @pulumi.getter(name="consumerGroupUserName")
    def consumer_group_user_name(self) -> pulumi.Output[str]:
        """
        The username of the consumer group. The length of the `consumer_group_user_name` is limited to `1` to `16` characters. It can contain one or more of the following characters: uppercase letters, lowercase letters, digits, and underscores (_).
        """
        return pulumi.get(self, "consumer_group_user_name")

    @property
    @pulumi.getter(name="dtsInstanceId")
    def dts_instance_id(self) -> pulumi.Output[str]:
        """
        The ID of the subscription instance.
        """
        return pulumi.get(self, "dts_instance_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'AggregateCompliancePackConfigRule',
    'AggregateCompliancePackConfigRuleConfigRuleParameter',
    'AggregateCompliancePackConfigRuleId',
    'AggregatorAggregatorAccount',
    'CompliancePackConfigRule',
    'CompliancePackConfigRuleConfigRuleParameter',
    'CompliancePackConfigRuleId',
    'RuleCompliance',
    'GetAggregateCompliancePacksPackResult',
    'GetAggregateCompliancePacksPackConfigRuleResult',
    'GetAggregateCompliancePacksPackConfigRuleConfigRuleParameterResult',
    'GetAggregateConfigRulesRuleResult',
    'GetAggregateConfigRulesRuleComplianceResult',
    'GetAggregateDeliveriesDeliveryResult',
    'GetAggregatorsAggregatorResult',
    'GetAggregatorsAggregatorAggregatorAccountResult',
    'GetCompliancePacksPackResult',
    'GetCompliancePacksPackConfigRuleResult',
    'GetCompliancePacksPackConfigRuleConfigRuleParameterResult',
    'GetConfigurationRecordersRecorderResult',
    'GetDeliveriesDeliveryResult',
    'GetDeliveryChannelsChannelResult',
    'GetRulesRuleResult',
    'GetRulesRuleComplianceResult',
]

@pulumi.output_type
class AggregateCompliancePackConfigRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "managedRuleIdentifier":
            suggest = "managed_rule_identifier"
        elif key == "configRuleParameters":
            suggest = "config_rule_parameters"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AggregateCompliancePackConfigRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AggregateCompliancePackConfigRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AggregateCompliancePackConfigRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 managed_rule_identifier: str,
                 config_rule_parameters: Optional[Sequence['outputs.AggregateCompliancePackConfigRuleConfigRuleParameter']] = None):
        """
        :param str managed_rule_identifier: The Managed Rule Identifier.
        :param Sequence['AggregateCompliancePackConfigRuleConfigRuleParameterArgs'] config_rule_parameters: A list of parameter rules. See `config_rule_parameters` below.
        """
        pulumi.set(__self__, "managed_rule_identifier", managed_rule_identifier)
        if config_rule_parameters is not None:
            pulumi.set(__self__, "config_rule_parameters", config_rule_parameters)

    @property
    @pulumi.getter(name="managedRuleIdentifier")
    def managed_rule_identifier(self) -> str:
        """
        The Managed Rule Identifier.
        """
        return pulumi.get(self, "managed_rule_identifier")

    @property
    @pulumi.getter(name="configRuleParameters")
    def config_rule_parameters(self) -> Optional[Sequence['outputs.AggregateCompliancePackConfigRuleConfigRuleParameter']]:
        """
        A list of parameter rules. See `config_rule_parameters` below.
        """
        return pulumi.get(self, "config_rule_parameters")


@pulumi.output_type
class AggregateCompliancePackConfigRuleConfigRuleParameter(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "parameterName":
            suggest = "parameter_name"
        elif key == "parameterValue":
            suggest = "parameter_value"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AggregateCompliancePackConfigRuleConfigRuleParameter. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AggregateCompliancePackConfigRuleConfigRuleParameter.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AggregateCompliancePackConfigRuleConfigRuleParameter.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 parameter_name: Optional[str] = None,
                 parameter_value: Optional[str] = None):
        """
        :param str parameter_name: The Parameter Name.
        :param str parameter_value: The Parameter Value.
        """
        if parameter_name is not None:
            pulumi.set(__self__, "parameter_name", parameter_name)
        if parameter_value is not None:
            pulumi.set(__self__, "parameter_value", parameter_value)

    @property
    @pulumi.getter(name="parameterName")
    def parameter_name(self) -> Optional[str]:
        """
        The Parameter Name.
        """
        return pulumi.get(self, "parameter_name")

    @property
    @pulumi.getter(name="parameterValue")
    def parameter_value(self) -> Optional[str]:
        """
        The Parameter Value.
        """
        return pulumi.get(self, "parameter_value")


@pulumi.output_type
class AggregateCompliancePackConfigRuleId(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "configRuleId":
            suggest = "config_rule_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AggregateCompliancePackConfigRuleId. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AggregateCompliancePackConfigRuleId.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AggregateCompliancePackConfigRuleId.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 config_rule_id: Optional[str] = None):
        """
        :param str config_rule_id: The rule ID of Aggregate Config Rule.
        """
        if config_rule_id is not None:
            pulumi.set(__self__, "config_rule_id", config_rule_id)

    @property
    @pulumi.getter(name="configRuleId")
    def config_rule_id(self) -> Optional[str]:
        """
        The rule ID of Aggregate Config Rule.
        """
        return pulumi.get(self, "config_rule_id")


@pulumi.output_type
class AggregatorAggregatorAccount(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "accountId":
            suggest = "account_id"
        elif key == "accountName":
            suggest = "account_name"
        elif key == "accountType":
            suggest = "account_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AggregatorAggregatorAccount. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AggregatorAggregatorAccount.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AggregatorAggregatorAccount.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 account_id: str,
                 account_name: str,
                 account_type: str):
        """
        :param str account_id: Aggregator account Uid.
        :param str account_name: Aggregator account name.
        :param str account_type: Aggregator account source type. Valid values: `ResourceDirectory`.
        """
        pulumi.set(__self__, "account_id", account_id)
        pulumi.set(__self__, "account_name", account_name)
        pulumi.set(__self__, "account_type", account_type)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> str:
        """
        Aggregator account Uid.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> str:
        """
        Aggregator account name.
        """
        return pulumi.get(self, "account_name")

    @property
    @pulumi.getter(name="accountType")
    def account_type(self) -> str:
        """
        Aggregator account source type. Valid values: `ResourceDirectory`.
        """
        return pulumi.get(self, "account_type")


@pulumi.output_type
class CompliancePackConfigRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "managedRuleIdentifier":
            suggest = "managed_rule_identifier"
        elif key == "configRuleParameters":
            suggest = "config_rule_parameters"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in CompliancePackConfigRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        CompliancePackConfigRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        CompliancePackConfigRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 managed_rule_identifier: str,
                 config_rule_parameters: Optional[Sequence['outputs.CompliancePackConfigRuleConfigRuleParameter']] = None):
        """
        :param str managed_rule_identifier: The Managed Rule Identifier.
        :param Sequence['CompliancePackConfigRuleConfigRuleParameterArgs'] config_rule_parameters: A list of Config Rule Parameters. See `config_rule_parameters` below.
        """
        pulumi.set(__self__, "managed_rule_identifier", managed_rule_identifier)
        if config_rule_parameters is not None:
            pulumi.set(__self__, "config_rule_parameters", config_rule_parameters)

    @property
    @pulumi.getter(name="managedRuleIdentifier")
    def managed_rule_identifier(self) -> str:
        """
        The Managed Rule Identifier.
        """
        return pulumi.get(self, "managed_rule_identifier")

    @property
    @pulumi.getter(name="configRuleParameters")
    def config_rule_parameters(self) -> Optional[Sequence['outputs.CompliancePackConfigRuleConfigRuleParameter']]:
        """
        A list of Config Rule Parameters. See `config_rule_parameters` below.
        """
        return pulumi.get(self, "config_rule_parameters")


@pulumi.output_type
class CompliancePackConfigRuleConfigRuleParameter(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "parameterName":
            suggest = "parameter_name"
        elif key == "parameterValue":
            suggest = "parameter_value"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in CompliancePackConfigRuleConfigRuleParameter. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        CompliancePackConfigRuleConfigRuleParameter.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        CompliancePackConfigRuleConfigRuleParameter.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 parameter_name: Optional[str] = None,
                 parameter_value: Optional[str] = None):
        """
        :param str parameter_name: The parameter name.
        :param str parameter_value: The parameter value.
        """
        if parameter_name is not None:
            pulumi.set(__self__, "parameter_name", parameter_name)
        if parameter_value is not None:
            pulumi.set(__self__, "parameter_value", parameter_value)

    @property
    @pulumi.getter(name="parameterName")
    def parameter_name(self) -> Optional[str]:
        """
        The parameter name.
        """
        return pulumi.get(self, "parameter_name")

    @property
    @pulumi.getter(name="parameterValue")
    def parameter_value(self) -> Optional[str]:
        """
        The parameter value.
        """
        return pulumi.get(self, "parameter_value")


@pulumi.output_type
class CompliancePackConfigRuleId(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "configRuleId":
            suggest = "config_rule_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in CompliancePackConfigRuleId. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        CompliancePackConfigRuleId.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        CompliancePackConfigRuleId.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 config_rule_id: Optional[str] = None):
        """
        :param str config_rule_id: The rule ID of Config Rule.
        """
        if config_rule_id is not None:
            pulumi.set(__self__, "config_rule_id", config_rule_id)

    @property
    @pulumi.getter(name="configRuleId")
    def config_rule_id(self) -> Optional[str]:
        """
        The rule ID of Config Rule.
        """
        return pulumi.get(self, "config_rule_id")


@pulumi.output_type
class RuleCompliance(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "complianceType":
            suggest = "compliance_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleCompliance. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleCompliance.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleCompliance.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 compliance_type: Optional[str] = None,
                 count: Optional[int] = None):
        """
        :param str compliance_type: The type of compliance. Valid values: `COMPLIANT`, `NON_COMPLIANT`, `NOT_APPLICABLE`, `INSUFFICIENT_DATA`.
        :param int count: The count of compliance.
        """
        if compliance_type is not None:
            pulumi.set(__self__, "compliance_type", compliance_type)
        if count is not None:
            pulumi.set(__self__, "count", count)

    @property
    @pulumi.getter(name="complianceType")
    def compliance_type(self) -> Optional[str]:
        """
        The type of compliance. Valid values: `COMPLIANT`, `NON_COMPLIANT`, `NOT_APPLICABLE`, `INSUFFICIENT_DATA`.
        """
        return pulumi.get(self, "compliance_type")

    @property
    @pulumi.getter
    def count(self) -> Optional[int]:
        """
        The count of compliance.
        """
        return pulumi.get(self, "count")


@pulumi.output_type
class GetAggregateCompliancePacksPackResult(dict):
    def __init__(__self__, *,
                 account_id: str,
                 aggregate_compliance_pack_name: str,
                 aggregator_compliance_pack_id: str,
                 compliance_pack_template_id: str,
                 config_rules: Sequence['outputs.GetAggregateCompliancePacksPackConfigRuleResult'],
                 description: str,
                 id: str,
                 risk_level: int,
                 status: str):
        """
        :param str account_id: The Aliyun User Id.
        :param str aggregate_compliance_pack_name: The Aggregate Compliance Package Name.
        :param str aggregator_compliance_pack_id: The Aggregate Compliance Package Id.
        :param str compliance_pack_template_id: The template ID of the Compliance Package.
        :param Sequence['GetAggregateCompliancePacksPackConfigRuleArgs'] config_rules: A list of The Aggregate Compliance Package Rules.
        :param str description: The description of aggregate compliance pack.
        :param str id: The ID of the Aggregate Compliance Pack.
        :param int risk_level: The Risk Level.
        :param str status: The status of the resource. Valid values `ACTIVE`, `CREATING`, `INACTIVE`.
        """
        pulumi.set(__self__, "account_id", account_id)
        pulumi.set(__self__, "aggregate_compliance_pack_name", aggregate_compliance_pack_name)
        pulumi.set(__self__, "aggregator_compliance_pack_id", aggregator_compliance_pack_id)
        pulumi.set(__self__, "compliance_pack_template_id", compliance_pack_template_id)
        pulumi.set(__self__, "config_rules", config_rules)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "risk_level", risk_level)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> str:
        """
        The Aliyun User Id.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="aggregateCompliancePackName")
    def aggregate_compliance_pack_name(self) -> str:
        """
        The Aggregate Compliance Package Name.
        """
        return pulumi.get(self, "aggregate_compliance_pack_name")

    @property
    @pulumi.getter(name="aggregatorCompliancePackId")
    def aggregator_compliance_pack_id(self) -> str:
        """
        The Aggregate Compliance Package Id.
        """
        return pulumi.get(self, "aggregator_compliance_pack_id")

    @property
    @pulumi.getter(name="compliancePackTemplateId")
    def compliance_pack_template_id(self) -> str:
        """
        The template ID of the Compliance Package.
        """
        return pulumi.get(self, "compliance_pack_template_id")

    @property
    @pulumi.getter(name="configRules")
    def config_rules(self) -> Sequence['outputs.GetAggregateCompliancePacksPackConfigRuleResult']:
        """
        A list of The Aggregate Compliance Package Rules.
        """
        return pulumi.get(self, "config_rules")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of aggregate compliance pack.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Aggregate Compliance Pack.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="riskLevel")
    def risk_level(self) -> int:
        """
        The Risk Level.
        """
        return pulumi.get(self, "risk_level")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the resource. Valid values `ACTIVE`, `CREATING`, `INACTIVE`.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetAggregateCompliancePacksPackConfigRuleResult(dict):
    def __init__(__self__, *,
                 config_rule_id: str,
                 config_rule_parameters: Sequence['outputs.GetAggregateCompliancePacksPackConfigRuleConfigRuleParameterResult'],
                 managed_rule_identifier: str):
        """
        :param str config_rule_id: The ID of the rule.
        :param Sequence['GetAggregateCompliancePacksPackConfigRuleConfigRuleParameterArgs'] config_rule_parameters: A list of parameter rules.
        :param str managed_rule_identifier: Managed Rule Identifier.
        """
        pulumi.set(__self__, "config_rule_id", config_rule_id)
        pulumi.set(__self__, "config_rule_parameters", config_rule_parameters)
        pulumi.set(__self__, "managed_rule_identifier", managed_rule_identifier)

    @property
    @pulumi.getter(name="configRuleId")
    def config_rule_id(self) -> str:
        """
        The ID of the rule.
        """
        return pulumi.get(self, "config_rule_id")

    @property
    @pulumi.getter(name="configRuleParameters")
    def config_rule_parameters(self) -> Sequence['outputs.GetAggregateCompliancePacksPackConfigRuleConfigRuleParameterResult']:
        """
        A list of parameter rules.
        """
        return pulumi.get(self, "config_rule_parameters")

    @property
    @pulumi.getter(name="managedRuleIdentifier")
    def managed_rule_identifier(self) -> str:
        """
        Managed Rule Identifier.
        """
        return pulumi.get(self, "managed_rule_identifier")


@pulumi.output_type
class GetAggregateCompliancePacksPackConfigRuleConfigRuleParameterResult(dict):
    def __init__(__self__, *,
                 parameter_name: str,
                 parameter_value: str,
                 required: bool):
        """
        :param str parameter_name: The Parameter Name.
        :param str parameter_value: The Parameter Value.
        :param bool required: Required.
        """
        pulumi.set(__self__, "parameter_name", parameter_name)
        pulumi.set(__self__, "parameter_value", parameter_value)
        pulumi.set(__self__, "required", required)

    @property
    @pulumi.getter(name="parameterName")
    def parameter_name(self) -> str:
        """
        The Parameter Name.
        """
        return pulumi.get(self, "parameter_name")

    @property
    @pulumi.getter(name="parameterValue")
    def parameter_value(self) -> str:
        """
        The Parameter Value.
        """
        return pulumi.get(self, "parameter_value")

    @property
    @pulumi.getter
    def required(self) -> bool:
        """
        Required.
        """
        return pulumi.get(self, "required")


@pulumi.output_type
class GetAggregateConfigRulesRuleResult(dict):
    def __init__(__self__, *,
                 account_id: str,
                 aggregate_config_rule_name: str,
                 aggregator_id: str,
                 compliance_pack_id: str,
                 compliances: Sequence['outputs.GetAggregateConfigRulesRuleComplianceResult'],
                 config_rule_arn: str,
                 config_rule_id: str,
                 config_rule_trigger_types: str,
                 description: str,
                 event_source: str,
                 exclude_resource_ids_scope: str,
                 id: str,
                 input_parameters: Mapping[str, Any],
                 maximum_execution_frequency: str,
                 modified_timestamp: str,
                 region_ids_scope: str,
                 resource_group_ids_scope: str,
                 resource_types_scopes: Sequence[str],
                 risk_level: int,
                 source_identifier: str,
                 source_owner: str,
                 status: str,
                 tag_key_scope: str,
                 tag_value_scope: str):
        """
        :param str account_id: The Aliyun User ID.
        :param str aggregate_config_rule_name: The config rule name.
        :param str aggregator_id: The ID of aggregator.
        :param str compliance_pack_id: The ID of Compliance Package.
        :param Sequence['GetAggregateConfigRulesRuleComplianceArgs'] compliances: The Compliance information.
        :param str config_rule_arn: The config rule arn.
        :param str config_rule_id: The ID of the rule.
        :param str config_rule_trigger_types: The trigger types of config rules.
        :param str description: The description of the rule.
        :param str event_source: Event source of the Config Rule.
        :param str exclude_resource_ids_scope: The id of the resources to be evaluated against the rule.
        :param str id: The ID of the Aggregate Config Rule.
        :param Mapping[str, Any] input_parameters: The settings of the input parameters for the rule.
        :param str maximum_execution_frequency: The frequency of the compliance evaluations.
        :param str modified_timestamp: The timestamp when the rule was last modified.
        :param str region_ids_scope: The scope of resource region ids.
        :param str resource_group_ids_scope: The scope of resource group ids.
        :param int risk_level: Optional, ForceNew) The Risk Level. Valid values `1`: critical, `2`: warning, `3`: info.
        :param str source_identifier: The identifier of the managed rule or the arn of the custom function.
        :param str source_owner: The source owner of the Config Rule.
        :param str status: The state of the config rule, valid values: `ACTIVE`, `DELETING`, `EVALUATING` and `INACTIVE`.
        :param str tag_key_scope: The scope of tay key.
        :param str tag_value_scope: The scope of tay value.
        """
        pulumi.set(__self__, "account_id", account_id)
        pulumi.set(__self__, "aggregate_config_rule_name", aggregate_config_rule_name)
        pulumi.set(__self__, "aggregator_id", aggregator_id)
        pulumi.set(__self__, "compliance_pack_id", compliance_pack_id)
        pulumi.set(__self__, "compliances", compliances)
        pulumi.set(__self__, "config_rule_arn", config_rule_arn)
        pulumi.set(__self__, "config_rule_id", config_rule_id)
        pulumi.set(__self__, "config_rule_trigger_types", config_rule_trigger_types)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "event_source", event_source)
        pulumi.set(__self__, "exclude_resource_ids_scope", exclude_resource_ids_scope)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "input_parameters", input_parameters)
        pulumi.set(__self__, "maximum_execution_frequency", maximum_execution_frequency)
        pulumi.set(__self__, "modified_timestamp", modified_timestamp)
        pulumi.set(__self__, "region_ids_scope", region_ids_scope)
        pulumi.set(__self__, "resource_group_ids_scope", resource_group_ids_scope)
        pulumi.set(__self__, "resource_types_scopes", resource_types_scopes)
        pulumi.set(__self__, "risk_level", risk_level)
        pulumi.set(__self__, "source_identifier", source_identifier)
        pulumi.set(__self__, "source_owner", source_owner)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "tag_key_scope", tag_key_scope)
        pulumi.set(__self__, "tag_value_scope", tag_value_scope)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> str:
        """
        The Aliyun User ID.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="aggregateConfigRuleName")
    def aggregate_config_rule_name(self) -> str:
        """
        The config rule name.
        """
        return pulumi.get(self, "aggregate_config_rule_name")

    @property
    @pulumi.getter(name="aggregatorId")
    def aggregator_id(self) -> str:
        """
        The ID of aggregator.
        """
        return pulumi.get(self, "aggregator_id")

    @property
    @pulumi.getter(name="compliancePackId")
    def compliance_pack_id(self) -> str:
        """
        The ID of Compliance Package.
        """
        return pulumi.get(self, "compliance_pack_id")

    @property
    @pulumi.getter
    def compliances(self) -> Sequence['outputs.GetAggregateConfigRulesRuleComplianceResult']:
        """
        The Compliance information.
        """
        return pulumi.get(self, "compliances")

    @property
    @pulumi.getter(name="configRuleArn")
    def config_rule_arn(self) -> str:
        """
        The config rule arn.
        """
        return pulumi.get(self, "config_rule_arn")

    @property
    @pulumi.getter(name="configRuleId")
    def config_rule_id(self) -> str:
        """
        The ID of the rule.
        """
        return pulumi.get(self, "config_rule_id")

    @property
    @pulumi.getter(name="configRuleTriggerTypes")
    def config_rule_trigger_types(self) -> str:
        """
        The trigger types of config rules.
        """
        return pulumi.get(self, "config_rule_trigger_types")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the rule.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="eventSource")
    def event_source(self) -> str:
        """
        Event source of the Config Rule.
        """
        return pulumi.get(self, "event_source")

    @property
    @pulumi.getter(name="excludeResourceIdsScope")
    def exclude_resource_ids_scope(self) -> str:
        """
        The id of the resources to be evaluated against the rule.
        """
        return pulumi.get(self, "exclude_resource_ids_scope")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Aggregate Config Rule.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="inputParameters")
    def input_parameters(self) -> Mapping[str, Any]:
        """
        The settings of the input parameters for the rule.
        """
        return pulumi.get(self, "input_parameters")

    @property
    @pulumi.getter(name="maximumExecutionFrequency")
    def maximum_execution_frequency(self) -> str:
        """
        The frequency of the compliance evaluations.
        """
        return pulumi.get(self, "maximum_execution_frequency")

    @property
    @pulumi.getter(name="modifiedTimestamp")
    def modified_timestamp(self) -> str:
        """
        The timestamp when the rule was last modified.
        """
        return pulumi.get(self, "modified_timestamp")

    @property
    @pulumi.getter(name="regionIdsScope")
    def region_ids_scope(self) -> str:
        """
        The scope of resource region ids.
        """
        return pulumi.get(self, "region_ids_scope")

    @property
    @pulumi.getter(name="resourceGroupIdsScope")
    def resource_group_ids_scope(self) -> str:
        """
        The scope of resource group ids.
        """
        return pulumi.get(self, "resource_group_ids_scope")

    @property
    @pulumi.getter(name="resourceTypesScopes")
    def resource_types_scopes(self) -> Sequence[str]:
        return pulumi.get(self, "resource_types_scopes")

    @property
    @pulumi.getter(name="riskLevel")
    def risk_level(self) -> int:
        """
        Optional, ForceNew) The Risk Level. Valid values `1`: critical, `2`: warning, `3`: info.
        """
        return pulumi.get(self, "risk_level")

    @property
    @pulumi.getter(name="sourceIdentifier")
    def source_identifier(self) -> str:
        """
        The identifier of the managed rule or the arn of the custom function.
        """
        return pulumi.get(self, "source_identifier")

    @property
    @pulumi.getter(name="sourceOwner")
    def source_owner(self) -> str:
        """
        The source owner of the Config Rule.
        """
        return pulumi.get(self, "source_owner")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The state of the config rule, valid values: `ACTIVE`, `DELETING`, `EVALUATING` and `INACTIVE`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="tagKeyScope")
    def tag_key_scope(self) -> str:
        """
        The scope of tay key.
        """
        return pulumi.get(self, "tag_key_scope")

    @property
    @pulumi.getter(name="tagValueScope")
    def tag_value_scope(self) -> str:
        """
        The scope of tay value.
        """
        return pulumi.get(self, "tag_value_scope")


@pulumi.output_type
class GetAggregateConfigRulesRuleComplianceResult(dict):
    def __init__(__self__, *,
                 compliance_type: str,
                 count: int):
        """
        :param str compliance_type: The Compliance Type.
        :param int count: The Count.
        """
        pulumi.set(__self__, "compliance_type", compliance_type)
        pulumi.set(__self__, "count", count)

    @property
    @pulumi.getter(name="complianceType")
    def compliance_type(self) -> str:
        """
        The Compliance Type.
        """
        return pulumi.get(self, "compliance_type")

    @property
    @pulumi.getter
    def count(self) -> int:
        """
        The Count.
        """
        return pulumi.get(self, "count")


@pulumi.output_type
class GetAggregateDeliveriesDeliveryResult(dict):
    def __init__(__self__, *,
                 account_id: str,
                 aggregator_id: str,
                 configuration_item_change_notification: bool,
                 configuration_snapshot: bool,
                 delivery_channel_assume_role_arn: str,
                 delivery_channel_condition: str,
                 delivery_channel_id: str,
                 delivery_channel_name: str,
                 delivery_channel_target_arn: str,
                 delivery_channel_type: str,
                 description: str,
                 id: str,
                 non_compliant_notification: bool,
                 oversized_data_oss_target_arn: str,
                 status: int):
        """
        :param str account_id: The Aliyun User Id.
        :param str aggregator_id: The ID of the Aggregator.
        :param bool configuration_item_change_notification: Open or close delivery configuration change history.
        :param bool configuration_snapshot: Open or close timed snapshot of shipping resources.
        :param str delivery_channel_assume_role_arn: The Alibaba Cloud Resource Name (ARN) of the role to be assumed by the delivery method.
        :param str delivery_channel_condition: The rule attached to the delivery method.
        :param str delivery_channel_id: The ID of the delivery method.
        :param str delivery_channel_name: The name of the delivery method.
        :param str delivery_channel_target_arn: The ARN of the delivery destination.
        :param str delivery_channel_type: The type of the delivery method.
        :param str description: The description of the delivery method.
        :param str id: The ID of the Aggregate Delivery.
        :param bool non_compliant_notification: Open or close non-compliance events of delivery resources.
        :param str oversized_data_oss_target_arn: The oss ARN of the delivery channel when the value data oversized limit.
        :param int status: The status of the delivery method. Valid values: `0`: The delivery method is disabled. `1`: The delivery destination is enabled.
        """
        pulumi.set(__self__, "account_id", account_id)
        pulumi.set(__self__, "aggregator_id", aggregator_id)
        pulumi.set(__self__, "configuration_item_change_notification", configuration_item_change_notification)
        pulumi.set(__self__, "configuration_snapshot", configuration_snapshot)
        pulumi.set(__self__, "delivery_channel_assume_role_arn", delivery_channel_assume_role_arn)
        pulumi.set(__self__, "delivery_channel_condition", delivery_channel_condition)
        pulumi.set(__self__, "delivery_channel_id", delivery_channel_id)
        pulumi.set(__self__, "delivery_channel_name", delivery_channel_name)
        pulumi.set(__self__, "delivery_channel_target_arn", delivery_channel_target_arn)
        pulumi.set(__self__, "delivery_channel_type", delivery_channel_type)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "non_compliant_notification", non_compliant_notification)
        pulumi.set(__self__, "oversized_data_oss_target_arn", oversized_data_oss_target_arn)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> str:
        """
        The Aliyun User Id.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="aggregatorId")
    def aggregator_id(self) -> str:
        """
        The ID of the Aggregator.
        """
        return pulumi.get(self, "aggregator_id")

    @property
    @pulumi.getter(name="configurationItemChangeNotification")
    def configuration_item_change_notification(self) -> bool:
        """
        Open or close delivery configuration change history.
        """
        return pulumi.get(self, "configuration_item_change_notification")

    @property
    @pulumi.getter(name="configurationSnapshot")
    def configuration_snapshot(self) -> bool:
        """
        Open or close timed snapshot of shipping resources.
        """
        return pulumi.get(self, "configuration_snapshot")

    @property
    @pulumi.getter(name="deliveryChannelAssumeRoleArn")
    def delivery_channel_assume_role_arn(self) -> str:
        """
        The Alibaba Cloud Resource Name (ARN) of the role to be assumed by the delivery method.
        """
        return pulumi.get(self, "delivery_channel_assume_role_arn")

    @property
    @pulumi.getter(name="deliveryChannelCondition")
    def delivery_channel_condition(self) -> str:
        """
        The rule attached to the delivery method.
        """
        return pulumi.get(self, "delivery_channel_condition")

    @property
    @pulumi.getter(name="deliveryChannelId")
    def delivery_channel_id(self) -> str:
        """
        The ID of the delivery method.
        """
        return pulumi.get(self, "delivery_channel_id")

    @property
    @pulumi.getter(name="deliveryChannelName")
    def delivery_channel_name(self) -> str:
        """
        The name of the delivery method.
        """
        return pulumi.get(self, "delivery_channel_name")

    @property
    @pulumi.getter(name="deliveryChannelTargetArn")
    def delivery_channel_target_arn(self) -> str:
        """
        The ARN of the delivery destination.
        """
        return pulumi.get(self, "delivery_channel_target_arn")

    @property
    @pulumi.getter(name="deliveryChannelType")
    def delivery_channel_type(self) -> str:
        """
        The type of the delivery method.
        """
        return pulumi.get(self, "delivery_channel_type")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the delivery method.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Aggregate Delivery.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="nonCompliantNotification")
    def non_compliant_notification(self) -> bool:
        """
        Open or close non-compliance events of delivery resources.
        """
        return pulumi.get(self, "non_compliant_notification")

    @property
    @pulumi.getter(name="oversizedDataOssTargetArn")
    def oversized_data_oss_target_arn(self) -> str:
        """
        The oss ARN of the delivery channel when the value data oversized limit.
        """
        return pulumi.get(self, "oversized_data_oss_target_arn")

    @property
    @pulumi.getter
    def status(self) -> int:
        """
        The status of the delivery method. Valid values: `0`: The delivery method is disabled. `1`: The delivery destination is enabled.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetAggregatorsAggregatorResult(dict):
    def __init__(__self__, *,
                 account_id: str,
                 aggregator_accounts: Sequence['outputs.GetAggregatorsAggregatorAggregatorAccountResult'],
                 aggregator_id: str,
                 aggregator_name: str,
                 aggregator_type: str,
                 description: str,
                 id: str,
                 status: str):
        """
        :param str account_id: Aggregator account uid.
        :param Sequence['GetAggregatorsAggregatorAggregatorAccountArgs'] aggregator_accounts: Account information in aggregator.
        :param str aggregator_id: The id of aggregator.
        :param str aggregator_name: The name of aggregator.
        :param str aggregator_type: The type of aggregator.
        :param str description: The description of aggregator.
        :param str id: The id of the aggregator.
        :param str status: The status of the resource. Valid Values:  `0`: creating `1`: normal `2`: deleting.
        """
        pulumi.set(__self__, "account_id", account_id)
        pulumi.set(__self__, "aggregator_accounts", aggregator_accounts)
        pulumi.set(__self__, "aggregator_id", aggregator_id)
        pulumi.set(__self__, "aggregator_name", aggregator_name)
        pulumi.set(__self__, "aggregator_type", aggregator_type)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> str:
        """
        Aggregator account uid.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="aggregatorAccounts")
    def aggregator_accounts(self) -> Sequence['outputs.GetAggregatorsAggregatorAggregatorAccountResult']:
        """
        Account information in aggregator.
        """
        return pulumi.get(self, "aggregator_accounts")

    @property
    @pulumi.getter(name="aggregatorId")
    def aggregator_id(self) -> str:
        """
        The id of aggregator.
        """
        return pulumi.get(self, "aggregator_id")

    @property
    @pulumi.getter(name="aggregatorName")
    def aggregator_name(self) -> str:
        """
        The name of aggregator.
        """
        return pulumi.get(self, "aggregator_name")

    @property
    @pulumi.getter(name="aggregatorType")
    def aggregator_type(self) -> str:
        """
        The type of aggregator.
        """
        return pulumi.get(self, "aggregator_type")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of aggregator.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The id of the aggregator.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the resource. Valid Values:  `0`: creating `1`: normal `2`: deleting.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetAggregatorsAggregatorAggregatorAccountResult(dict):
    def __init__(__self__, *,
                 account_id: str,
                 account_name: str,
                 account_type: str):
        """
        :param str account_id: Aggregator account uid.
        :param str account_name: Aggregator account name.
        :param str account_type: Aggregator account source type.
        """
        pulumi.set(__self__, "account_id", account_id)
        pulumi.set(__self__, "account_name", account_name)
        pulumi.set(__self__, "account_type", account_type)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> str:
        """
        Aggregator account uid.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> str:
        """
        Aggregator account name.
        """
        return pulumi.get(self, "account_name")

    @property
    @pulumi.getter(name="accountType")
    def account_type(self) -> str:
        """
        Aggregator account source type.
        """
        return pulumi.get(self, "account_type")


@pulumi.output_type
class GetCompliancePacksPackResult(dict):
    def __init__(__self__, *,
                 account_id: str,
                 compliance_pack_id: str,
                 compliance_pack_name: str,
                 compliance_pack_template_id: str,
                 config_rules: Sequence['outputs.GetCompliancePacksPackConfigRuleResult'],
                 description: str,
                 id: str,
                 risk_level: int,
                 status: str):
        """
        :param str account_id: The Aliyun User Id.
        :param str compliance_pack_id: The Compliance Package ID.
        :param str compliance_pack_name: The Compliance Package Name.
        :param str compliance_pack_template_id: The template ID of the Compliance Package.
        :param Sequence['GetCompliancePacksPackConfigRuleArgs'] config_rules: A list of The Compliance Package Rules.
        :param str description: The description of compliance pack.
        :param str id: The ID of the Compliance Pack.
        :param int risk_level: The Ris Level.
        :param str status: The status of the resource. Valid values `ACTIVE`, `CREATING`.
        """
        pulumi.set(__self__, "account_id", account_id)
        pulumi.set(__self__, "compliance_pack_id", compliance_pack_id)
        pulumi.set(__self__, "compliance_pack_name", compliance_pack_name)
        pulumi.set(__self__, "compliance_pack_template_id", compliance_pack_template_id)
        pulumi.set(__self__, "config_rules", config_rules)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "risk_level", risk_level)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> str:
        """
        The Aliyun User Id.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="compliancePackId")
    def compliance_pack_id(self) -> str:
        """
        The Compliance Package ID.
        """
        return pulumi.get(self, "compliance_pack_id")

    @property
    @pulumi.getter(name="compliancePackName")
    def compliance_pack_name(self) -> str:
        """
        The Compliance Package Name.
        """
        return pulumi.get(self, "compliance_pack_name")

    @property
    @pulumi.getter(name="compliancePackTemplateId")
    def compliance_pack_template_id(self) -> str:
        """
        The template ID of the Compliance Package.
        """
        return pulumi.get(self, "compliance_pack_template_id")

    @property
    @pulumi.getter(name="configRules")
    def config_rules(self) -> Sequence['outputs.GetCompliancePacksPackConfigRuleResult']:
        """
        A list of The Compliance Package Rules.
        """
        return pulumi.get(self, "config_rules")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of compliance pack.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Compliance Pack.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="riskLevel")
    def risk_level(self) -> int:
        """
        The Ris Level.
        """
        return pulumi.get(self, "risk_level")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the resource. Valid values `ACTIVE`, `CREATING`.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetCompliancePacksPackConfigRuleResult(dict):
    def __init__(__self__, *,
                 config_rule_id: str,
                 config_rule_parameters: Sequence['outputs.GetCompliancePacksPackConfigRuleConfigRuleParameterResult'],
                 managed_rule_identifier: str):
        """
        :param str config_rule_id: The ID of the rule.
        :param Sequence['GetCompliancePacksPackConfigRuleConfigRuleParameterArgs'] config_rule_parameters: A list of parameter rules.
        :param str managed_rule_identifier: Managed Rule Identifier.
        """
        pulumi.set(__self__, "config_rule_id", config_rule_id)
        pulumi.set(__self__, "config_rule_parameters", config_rule_parameters)
        pulumi.set(__self__, "managed_rule_identifier", managed_rule_identifier)

    @property
    @pulumi.getter(name="configRuleId")
    def config_rule_id(self) -> str:
        """
        The ID of the rule.
        """
        return pulumi.get(self, "config_rule_id")

    @property
    @pulumi.getter(name="configRuleParameters")
    def config_rule_parameters(self) -> Sequence['outputs.GetCompliancePacksPackConfigRuleConfigRuleParameterResult']:
        """
        A list of parameter rules.
        """
        return pulumi.get(self, "config_rule_parameters")

    @property
    @pulumi.getter(name="managedRuleIdentifier")
    def managed_rule_identifier(self) -> str:
        """
        Managed Rule Identifier.
        """
        return pulumi.get(self, "managed_rule_identifier")


@pulumi.output_type
class GetCompliancePacksPackConfigRuleConfigRuleParameterResult(dict):
    def __init__(__self__, *,
                 parameter_name: str,
                 parameter_value: str,
                 required: bool):
        """
        :param str parameter_name: The Parameter Name.
        :param str parameter_value: The Parameter Value.
        :param bool required: Required.
        """
        pulumi.set(__self__, "parameter_name", parameter_name)
        pulumi.set(__self__, "parameter_value", parameter_value)
        pulumi.set(__self__, "required", required)

    @property
    @pulumi.getter(name="parameterName")
    def parameter_name(self) -> str:
        """
        The Parameter Name.
        """
        return pulumi.get(self, "parameter_name")

    @property
    @pulumi.getter(name="parameterValue")
    def parameter_value(self) -> str:
        """
        The Parameter Value.
        """
        return pulumi.get(self, "parameter_value")

    @property
    @pulumi.getter
    def required(self) -> bool:
        """
        Required.
        """
        return pulumi.get(self, "required")


@pulumi.output_type
class GetConfigurationRecordersRecorderResult(dict):
    def __init__(__self__, *,
                 account_id: str,
                 id: str,
                 organization_enable_status: str,
                 organization_master_id: int,
                 resource_types: Sequence[str],
                 status: str):
        """
        :param str account_id: The ID of the Alicloud account.
        :param str id: The ID of the Config Configuration Recorder. Value as the `account_id`.
        :param str organization_enable_status: Enterprise version configuration audit enabled status.
        :param int organization_master_id: The ID of the Enterprise management account.
        :param Sequence[str] resource_types: A list of resource types to be monitored.
        :param str status: Status of resource monitoring.
        """
        pulumi.set(__self__, "account_id", account_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "organization_enable_status", organization_enable_status)
        pulumi.set(__self__, "organization_master_id", organization_master_id)
        pulumi.set(__self__, "resource_types", resource_types)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> str:
        """
        The ID of the Alicloud account.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Config Configuration Recorder. Value as the `account_id`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="organizationEnableStatus")
    def organization_enable_status(self) -> str:
        """
        Enterprise version configuration audit enabled status.
        """
        return pulumi.get(self, "organization_enable_status")

    @property
    @pulumi.getter(name="organizationMasterId")
    def organization_master_id(self) -> int:
        """
        The ID of the Enterprise management account.
        """
        return pulumi.get(self, "organization_master_id")

    @property
    @pulumi.getter(name="resourceTypes")
    def resource_types(self) -> Sequence[str]:
        """
        A list of resource types to be monitored.
        """
        return pulumi.get(self, "resource_types")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Status of resource monitoring.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetDeliveriesDeliveryResult(dict):
    def __init__(__self__, *,
                 account_id: str,
                 configuration_item_change_notification: bool,
                 configuration_snapshot: bool,
                 delivery_channel_assume_role_arn: str,
                 delivery_channel_condition: str,
                 delivery_channel_id: str,
                 delivery_channel_name: str,
                 delivery_channel_target_arn: str,
                 delivery_channel_type: str,
                 description: str,
                 id: str,
                 non_compliant_notification: bool,
                 oversized_data_oss_target_arn: str,
                 status: int):
        """
        :param str account_id: The Aliyun User Id.
        :param bool configuration_item_change_notification: Open or close delivery configuration change history.
        :param bool configuration_snapshot: Open or close timed snapshot of shipping resources.
        :param str delivery_channel_assume_role_arn: The Alibaba Cloud Resource Name (ARN) of the role to be assumed by the delivery method.
        :param str delivery_channel_condition: The rule attached to the delivery method.
        :param str delivery_channel_id: The ID of the delivery method.
        :param str delivery_channel_name: The name of the delivery method.
        :param str delivery_channel_target_arn: The ARN of the delivery destination.
        :param str delivery_channel_type: The type of the delivery method.
        :param str description: The description of the delivery method.
        :param str id: The ID of the Delivery.
        :param bool non_compliant_notification: Open or close non-compliance events of delivery resources.
        :param str oversized_data_oss_target_arn: The oss ARN of the delivery channel when the value data oversized limit.
        :param int status: The status of the delivery method. Valid values: `0`: The delivery method is disabled. `1`: The delivery destination is enabled.
        """
        pulumi.set(__self__, "account_id", account_id)
        pulumi.set(__self__, "configuration_item_change_notification", configuration_item_change_notification)
        pulumi.set(__self__, "configuration_snapshot", configuration_snapshot)
        pulumi.set(__self__, "delivery_channel_assume_role_arn", delivery_channel_assume_role_arn)
        pulumi.set(__self__, "delivery_channel_condition", delivery_channel_condition)
        pulumi.set(__self__, "delivery_channel_id", delivery_channel_id)
        pulumi.set(__self__, "delivery_channel_name", delivery_channel_name)
        pulumi.set(__self__, "delivery_channel_target_arn", delivery_channel_target_arn)
        pulumi.set(__self__, "delivery_channel_type", delivery_channel_type)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "non_compliant_notification", non_compliant_notification)
        pulumi.set(__self__, "oversized_data_oss_target_arn", oversized_data_oss_target_arn)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> str:
        """
        The Aliyun User Id.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="configurationItemChangeNotification")
    def configuration_item_change_notification(self) -> bool:
        """
        Open or close delivery configuration change history.
        """
        return pulumi.get(self, "configuration_item_change_notification")

    @property
    @pulumi.getter(name="configurationSnapshot")
    def configuration_snapshot(self) -> bool:
        """
        Open or close timed snapshot of shipping resources.
        """
        return pulumi.get(self, "configuration_snapshot")

    @property
    @pulumi.getter(name="deliveryChannelAssumeRoleArn")
    def delivery_channel_assume_role_arn(self) -> str:
        """
        The Alibaba Cloud Resource Name (ARN) of the role to be assumed by the delivery method.
        """
        return pulumi.get(self, "delivery_channel_assume_role_arn")

    @property
    @pulumi.getter(name="deliveryChannelCondition")
    def delivery_channel_condition(self) -> str:
        """
        The rule attached to the delivery method.
        """
        return pulumi.get(self, "delivery_channel_condition")

    @property
    @pulumi.getter(name="deliveryChannelId")
    def delivery_channel_id(self) -> str:
        """
        The ID of the delivery method.
        """
        return pulumi.get(self, "delivery_channel_id")

    @property
    @pulumi.getter(name="deliveryChannelName")
    def delivery_channel_name(self) -> str:
        """
        The name of the delivery method.
        """
        return pulumi.get(self, "delivery_channel_name")

    @property
    @pulumi.getter(name="deliveryChannelTargetArn")
    def delivery_channel_target_arn(self) -> str:
        """
        The ARN of the delivery destination.
        """
        return pulumi.get(self, "delivery_channel_target_arn")

    @property
    @pulumi.getter(name="deliveryChannelType")
    def delivery_channel_type(self) -> str:
        """
        The type of the delivery method.
        """
        return pulumi.get(self, "delivery_channel_type")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the delivery method.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Delivery.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="nonCompliantNotification")
    def non_compliant_notification(self) -> bool:
        """
        Open or close non-compliance events of delivery resources.
        """
        return pulumi.get(self, "non_compliant_notification")

    @property
    @pulumi.getter(name="oversizedDataOssTargetArn")
    def oversized_data_oss_target_arn(self) -> str:
        """
        The oss ARN of the delivery channel when the value data oversized limit.
        """
        return pulumi.get(self, "oversized_data_oss_target_arn")

    @property
    @pulumi.getter
    def status(self) -> int:
        """
        The status of the delivery method. Valid values: `0`: The delivery method is disabled. `1`: The delivery destination is enabled.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetDeliveryChannelsChannelResult(dict):
    def __init__(__self__, *,
                 delivery_channel_assume_role_arn: str,
                 delivery_channel_condition: str,
                 delivery_channel_id: str,
                 delivery_channel_name: str,
                 delivery_channel_target_arn: str,
                 delivery_channel_type: str,
                 description: str,
                 id: str,
                 status: int):
        """
        :param str delivery_channel_assume_role_arn: The Alibaba Cloud Resource Name (ARN) of the role assumed by delivery method.
        :param str delivery_channel_condition: The rule attached to the delivery method. This parameter is applicable only to delivery methods of the Message Service (MNS) type.
        :param str delivery_channel_id: The ID of the delivery channel.
        :param str delivery_channel_name: The name of the delivery channel.
        :param str delivery_channel_target_arn: The ARN of the delivery destination.
        :param str delivery_channel_type: The type of the delivery channel.
        :param str description: The description of the delivery channel.
        :param str id: The ID of the Config Delivery Channel.
        :param int status: The status of the config delivery channel. Valid values `0`: Disable delivery channel, `1`: Enable delivery channel.
        """
        pulumi.set(__self__, "delivery_channel_assume_role_arn", delivery_channel_assume_role_arn)
        pulumi.set(__self__, "delivery_channel_condition", delivery_channel_condition)
        pulumi.set(__self__, "delivery_channel_id", delivery_channel_id)
        pulumi.set(__self__, "delivery_channel_name", delivery_channel_name)
        pulumi.set(__self__, "delivery_channel_target_arn", delivery_channel_target_arn)
        pulumi.set(__self__, "delivery_channel_type", delivery_channel_type)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="deliveryChannelAssumeRoleArn")
    def delivery_channel_assume_role_arn(self) -> str:
        """
        The Alibaba Cloud Resource Name (ARN) of the role assumed by delivery method.
        """
        return pulumi.get(self, "delivery_channel_assume_role_arn")

    @property
    @pulumi.getter(name="deliveryChannelCondition")
    def delivery_channel_condition(self) -> str:
        """
        The rule attached to the delivery method. This parameter is applicable only to delivery methods of the Message Service (MNS) type.
        """
        return pulumi.get(self, "delivery_channel_condition")

    @property
    @pulumi.getter(name="deliveryChannelId")
    def delivery_channel_id(self) -> str:
        """
        The ID of the delivery channel.
        """
        return pulumi.get(self, "delivery_channel_id")

    @property
    @pulumi.getter(name="deliveryChannelName")
    def delivery_channel_name(self) -> str:
        """
        The name of the delivery channel.
        """
        return pulumi.get(self, "delivery_channel_name")

    @property
    @pulumi.getter(name="deliveryChannelTargetArn")
    def delivery_channel_target_arn(self) -> str:
        """
        The ARN of the delivery destination.
        """
        return pulumi.get(self, "delivery_channel_target_arn")

    @property
    @pulumi.getter(name="deliveryChannelType")
    def delivery_channel_type(self) -> str:
        """
        The type of the delivery channel.
        """
        return pulumi.get(self, "delivery_channel_type")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the delivery channel.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Config Delivery Channel.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def status(self) -> int:
        """
        The status of the config delivery channel. Valid values `0`: Disable delivery channel, `1`: Enable delivery channel.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetRulesRuleResult(dict):
    def __init__(__self__, *,
                 account_id: str,
                 compliance_pack_id: str,
                 compliances: Sequence['outputs.GetRulesRuleComplianceResult'],
                 config_rule_arn: str,
                 config_rule_id: str,
                 config_rule_state: str,
                 config_rule_trigger_types: str,
                 description: str,
                 event_source: str,
                 exclude_resource_ids_scope: str,
                 id: str,
                 input_parameters: Mapping[str, Any],
                 maximum_execution_frequency: str,
                 modified_timestamp: str,
                 region_ids_scope: str,
                 resource_group_ids_scope: str,
                 resource_types_scopes: Sequence[str],
                 risk_level: int,
                 rule_name: str,
                 scope_compliance_resource_types: Sequence[str],
                 source_detail_message_type: str,
                 source_identifier: str,
                 source_maximum_execution_frequency: str,
                 source_owner: str,
                 status: str,
                 tag_key_scope: str,
                 tag_value_scope: str):
        """
        :param str account_id: The ID of the Alicloud account.
        :param Sequence['GetRulesRuleComplianceArgs'] compliances: The information about the compliance evaluations based on the rule.
        :param str config_rule_arn: The ARN of the Config Rule.
        :param str config_rule_id: The ID of the Config Rule.
        :param str config_rule_state: Field `config_rule_state` has been deprecated from provider version 1.124.1. New field `status` instead.
        :param str config_rule_trigger_types: (Available in 1.124.1+) A list of trigger types of config rule.
        :param str description: The description of the Config Rule.
        :param str event_source: Event source of the Config Rule.
        :param str exclude_resource_ids_scope: (Available in 1.124.1+) The scope of exclude of resource ids.
        :param str id: The ID of the Config Rule.
        :param Mapping[str, Any] input_parameters: The input parameters of the Config Rule.
        :param str maximum_execution_frequency: (Available in 1.124.1+) The frequency of maximum execution.
        :param str modified_timestamp: the timestamp of the Config Rule modified.
        :param str region_ids_scope: (Available in 1.124.1+) The scope of region ids.
        :param str resource_group_ids_scope: (Available in 1.124.1+) The scope of resource group ids.
        :param Sequence[str] resource_types_scopes: (Available in 1.124.1+) The scope of resource types.
        :param int risk_level: The risk level of Config Rule. Valid values: `1`: Critical ,`2`: Warning , `3`: Info.
        :param str rule_name: The name of config rule.
        :param Sequence[str] scope_compliance_resource_types: The types of the resources to be evaluated against the rule.
        :param str source_detail_message_type: Rule trigger mechanism.
        :param str source_identifier: The identifier of the managed rule or the arn of the custom function.
        :param str source_maximum_execution_frequency: Rule execution cycle.
        :param str source_owner: The source owner of the Config Rule.
        :param str status: The status of the config rule, valid values: `ACTIVE`, `DELETING`, `EVALUATING` and `INACTIVE`.
        :param str tag_key_scope: (Available in 1.124.1+) The scope of tag key.
        :param str tag_value_scope: (Available in 1.124.1+) The scope of tag value.
        """
        pulumi.set(__self__, "account_id", account_id)
        pulumi.set(__self__, "compliance_pack_id", compliance_pack_id)
        pulumi.set(__self__, "compliances", compliances)
        pulumi.set(__self__, "config_rule_arn", config_rule_arn)
        pulumi.set(__self__, "config_rule_id", config_rule_id)
        pulumi.set(__self__, "config_rule_state", config_rule_state)
        pulumi.set(__self__, "config_rule_trigger_types", config_rule_trigger_types)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "event_source", event_source)
        pulumi.set(__self__, "exclude_resource_ids_scope", exclude_resource_ids_scope)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "input_parameters", input_parameters)
        pulumi.set(__self__, "maximum_execution_frequency", maximum_execution_frequency)
        pulumi.set(__self__, "modified_timestamp", modified_timestamp)
        pulumi.set(__self__, "region_ids_scope", region_ids_scope)
        pulumi.set(__self__, "resource_group_ids_scope", resource_group_ids_scope)
        pulumi.set(__self__, "resource_types_scopes", resource_types_scopes)
        pulumi.set(__self__, "risk_level", risk_level)
        pulumi.set(__self__, "rule_name", rule_name)
        pulumi.set(__self__, "scope_compliance_resource_types", scope_compliance_resource_types)
        pulumi.set(__self__, "source_detail_message_type", source_detail_message_type)
        pulumi.set(__self__, "source_identifier", source_identifier)
        pulumi.set(__self__, "source_maximum_execution_frequency", source_maximum_execution_frequency)
        pulumi.set(__self__, "source_owner", source_owner)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "tag_key_scope", tag_key_scope)
        pulumi.set(__self__, "tag_value_scope", tag_value_scope)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> str:
        """
        The ID of the Alicloud account.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="compliancePackId")
    def compliance_pack_id(self) -> str:
        return pulumi.get(self, "compliance_pack_id")

    @property
    @pulumi.getter
    def compliances(self) -> Sequence['outputs.GetRulesRuleComplianceResult']:
        """
        The information about the compliance evaluations based on the rule.
        """
        return pulumi.get(self, "compliances")

    @property
    @pulumi.getter(name="configRuleArn")
    def config_rule_arn(self) -> str:
        """
        The ARN of the Config Rule.
        """
        return pulumi.get(self, "config_rule_arn")

    @property
    @pulumi.getter(name="configRuleId")
    def config_rule_id(self) -> str:
        """
        The ID of the Config Rule.
        """
        return pulumi.get(self, "config_rule_id")

    @property
    @pulumi.getter(name="configRuleState")
    def config_rule_state(self) -> str:
        """
        Field `config_rule_state` has been deprecated from provider version 1.124.1. New field `status` instead.
        """
        return pulumi.get(self, "config_rule_state")

    @property
    @pulumi.getter(name="configRuleTriggerTypes")
    def config_rule_trigger_types(self) -> str:
        """
        (Available in 1.124.1+) A list of trigger types of config rule.
        """
        return pulumi.get(self, "config_rule_trigger_types")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the Config Rule.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="eventSource")
    def event_source(self) -> str:
        """
        Event source of the Config Rule.
        """
        return pulumi.get(self, "event_source")

    @property
    @pulumi.getter(name="excludeResourceIdsScope")
    def exclude_resource_ids_scope(self) -> str:
        """
        (Available in 1.124.1+) The scope of exclude of resource ids.
        """
        return pulumi.get(self, "exclude_resource_ids_scope")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Config Rule.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="inputParameters")
    def input_parameters(self) -> Mapping[str, Any]:
        """
        The input parameters of the Config Rule.
        """
        return pulumi.get(self, "input_parameters")

    @property
    @pulumi.getter(name="maximumExecutionFrequency")
    def maximum_execution_frequency(self) -> str:
        """
        (Available in 1.124.1+) The frequency of maximum execution.
        """
        return pulumi.get(self, "maximum_execution_frequency")

    @property
    @pulumi.getter(name="modifiedTimestamp")
    def modified_timestamp(self) -> str:
        """
        the timestamp of the Config Rule modified.
        """
        return pulumi.get(self, "modified_timestamp")

    @property
    @pulumi.getter(name="regionIdsScope")
    def region_ids_scope(self) -> str:
        """
        (Available in 1.124.1+) The scope of region ids.
        """
        return pulumi.get(self, "region_ids_scope")

    @property
    @pulumi.getter(name="resourceGroupIdsScope")
    def resource_group_ids_scope(self) -> str:
        """
        (Available in 1.124.1+) The scope of resource group ids.
        """
        return pulumi.get(self, "resource_group_ids_scope")

    @property
    @pulumi.getter(name="resourceTypesScopes")
    def resource_types_scopes(self) -> Sequence[str]:
        """
        (Available in 1.124.1+) The scope of resource types.
        """
        return pulumi.get(self, "resource_types_scopes")

    @property
    @pulumi.getter(name="riskLevel")
    def risk_level(self) -> int:
        """
        The risk level of Config Rule. Valid values: `1`: Critical ,`2`: Warning , `3`: Info.
        """
        return pulumi.get(self, "risk_level")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> str:
        """
        The name of config rule.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="scopeComplianceResourceTypes")
    def scope_compliance_resource_types(self) -> Sequence[str]:
        """
        The types of the resources to be evaluated against the rule.
        """
        return pulumi.get(self, "scope_compliance_resource_types")

    @property
    @pulumi.getter(name="sourceDetailMessageType")
    def source_detail_message_type(self) -> str:
        """
        Rule trigger mechanism.
        """
        return pulumi.get(self, "source_detail_message_type")

    @property
    @pulumi.getter(name="sourceIdentifier")
    def source_identifier(self) -> str:
        """
        The identifier of the managed rule or the arn of the custom function.
        """
        return pulumi.get(self, "source_identifier")

    @property
    @pulumi.getter(name="sourceMaximumExecutionFrequency")
    def source_maximum_execution_frequency(self) -> str:
        """
        Rule execution cycle.
        """
        return pulumi.get(self, "source_maximum_execution_frequency")

    @property
    @pulumi.getter(name="sourceOwner")
    def source_owner(self) -> str:
        """
        The source owner of the Config Rule.
        """
        return pulumi.get(self, "source_owner")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the config rule, valid values: `ACTIVE`, `DELETING`, `EVALUATING` and `INACTIVE`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="tagKeyScope")
    def tag_key_scope(self) -> str:
        """
        (Available in 1.124.1+) The scope of tag key.
        """
        return pulumi.get(self, "tag_key_scope")

    @property
    @pulumi.getter(name="tagValueScope")
    def tag_value_scope(self) -> str:
        """
        (Available in 1.124.1+) The scope of tag value.
        """
        return pulumi.get(self, "tag_value_scope")


@pulumi.output_type
class GetRulesRuleComplianceResult(dict):
    def __init__(__self__, *,
                 compliance_type: str,
                 count: int):
        """
        :param str compliance_type: The compliance evaluation result of the target resources.
        :param int count: The number of resources with the specified compliance evaluation result.
        """
        pulumi.set(__self__, "compliance_type", compliance_type)
        pulumi.set(__self__, "count", count)

    @property
    @pulumi.getter(name="complianceType")
    def compliance_type(self) -> str:
        """
        The compliance evaluation result of the target resources.
        """
        return pulumi.get(self, "compliance_type")

    @property
    @pulumi.getter
    def count(self) -> int:
        """
        The number of resources with the specified compliance evaluation result.
        """
        return pulumi.get(self, "count")


